"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Cell = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _icon = _interopRequireDefault(require("../icon"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const defaultProps = {
  title: null,
  subTitle: null,
  desc: '',
  descTextAlign: 'right',
  isLink: false,
  icon: '',
  roundRadius: 6,
  // url: '',
  // to: '',
  // replace: false,
  center: false,
  size: '',
  iconSlot: null,
  linkSlot: null,
  cellGroup: false,
  isLast: false
};
const Cell = props => {
  const {
    children,
    onClick,
    title,
    subTitle,
    desc,
    descTextAlign,
    isLink,
    icon,
    roundRadius,
    center,
    size,
    iconSlot,
    linkSlot,
    cellGroup,
    isLast,
    style
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const handleClick = event => {
    onClick && onClick(event);
  };
  const baseStyle = {
    borderRadius: roundRadius
  };
  const tTextStyle = [styles.tText, styles[`tTextSize${size}`]];
  const subTextStyle = [styles.subText, styles[`subTextSize${size}`]];
  const descCStyle = [styles.descC, center ? {
    alignSelf: 'center'
  } : {}, title || subTitle || icon ? {} : {
    textAlign: descTextAlign,
    flex: 1
  }];
  const descTextStyle = [styles.descText, styles[`descAlone${!title && !subTitle}`], styles[`descSize${size}`]];
  const innerStyle = [styles.innerStyle, styles[`innerCenter${center}`], (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {}))];
  const renderComponent = () => {
    if (children) {
      return children;
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: innerStyle
    }, /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, iconSlot || null, icon ? /*#__PURE__*/_react.default.createElement(_icon.default, {
      name: icon,
      style: styles.icon,
      size: 18
    }) : null, title || subTitle ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.titleContainer
    }, title ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: tTextStyle
    }, title) : null, subTitle ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: subTextStyle
    }, subTitle) : null) : null), /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, desc ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: descCStyle
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: descTextStyle
    }, desc)) : null, !linkSlot && isLink ? /*#__PURE__*/_react.default.createElement(_icon.default, {
      name: "right",
      color: "#979797",
      size: 14
    }) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null, linkSlot)));
  };
  const wrapStyle = [styles.container, styles[`container${size}`], styles[`containerCellGroup${cellGroup}`], styles[`containerIsLast${isLast}`], baseStyle];
  if (isLink) {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableHighlight, {
      style: [baseStyle, {
        width: '100%'
      }],
      activeOpacity: 1,
      underlayColor: null,
      onPress: handleClick
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: wrapStyle
    }, renderComponent()));
  }
  if (onClick) {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableHighlight, {
      style: [baseStyle, {
        width: '100%'
      }],
      activeOpacity: 1,
      underlayColor: null,
      onPress: onClick
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: wrapStyle
    }, renderComponent()));
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, renderComponent());
};
exports.Cell = Cell;
Cell.defaultProps = defaultProps;
Cell.displayName = 'NutCell';
//# sourceMappingURL=cell.js.map