"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Divider = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _filterContainerStyleWithoutBorder = _interopRequireDefault(require("../utils/filter-container-style-without-border"));
var _filterBorderStyle = _interopRequireDefault(require("../utils/filter-border-style"));
var _filterTextStyle = _interopRequireDefault(require("../utils/filter-text-style"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const defaultProps = {
  contentPosition: 'center',
  // 内容位置，可选值为left right
  dashed: false,
  // 是否使用虚线
  hairline: true,
  // 是否使用 0.5px 线, RN 0.5有兼容性问题
  direction: 'horizontal' // 水平还是垂直类型
};

const renderChilden = (children, styles, contentPosition, dashed, hairline, myStyles) => {
  const Component = typeof children === 'string' ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    key: 2,
    style: [myStyles.text, (0, _filterTextStyle.default)((0, _styleToObj.default)(styles))]
  }, children) : children;
  return [/*#__PURE__*/_react.default.createElement(_reactNative.View, {
    key: 1,
    style: [myStyles[`left${contentPosition}`], myStyles[`lineStyle${dashed}`], myStyles[`lineWidth${hairline}`], (0, _filterBorderStyle.default)((0, _styleToObj.default)(styles))]
  }), Component, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    key: 3,
    style: [myStyles[`right${contentPosition}`], myStyles[`lineStyle${dashed}`], myStyles[`lineWidth${hairline}`], (0, _filterBorderStyle.default)((0, _styleToObj.default)(styles))]
  })];
};
const Divider = props => {
  const {
    children,
    contentPosition,
    dashed,
    hairline,
    direction,
    styles
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const myStyles = (0, _styles.default)(theme);
  let wrapStyle;
  if (direction === 'vertical') {
    wrapStyle = [myStyles.verticalStyle, (0, _styleToObj.default)(styles || {})];
  } else {
    wrapStyle = [myStyles[`row${!!children}Style`], myStyles[`dashed${dashed}${!!children}`] || {}, myStyles[`hairline${dashed}${hairline}${!!children}`] || {}, !children ? (0, _styleToObj.default)(styles || {}) : {} // 没有子元素或将props 样式传递
    ];
  }

  if (!children) {
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: wrapStyle
    });
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [wrapStyle, (0, _filterContainerStyleWithoutBorder.default)((0, _styleToObj.default)(styles || {}))]
  }, renderChilden(children, styles, contentPosition, dashed, hairline, myStyles));
};
exports.Divider = Divider;
Divider.displayName = 'NutDivider';
//# sourceMappingURL=divider.js.map