"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GridItem = void 0;
var _react = _interopRequireWildcard(require("react"));
var _index = _interopRequireDefault(require("../icon/index"));
var _reactNative = require("react-native");
var _typings = require("../utils/typings");
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  ..._typings.ComponentDefaults,
  text: '',
  icon: '',
  iconSize: '',
  iconColor: '',
  parentIconSize: '',
  parentIconColor: '',
  columnNum: 4,
  border: true,
  gutter: 0,
  center: true,
  square: false,
  reverse: false,
  direction: 'vertical',
  onPress: () => {}
};
const GridItem = props => {
  //const { locale } = useConfig()
  const {
    children,
    columnNum,
    index,
    gutter,
    square,
    text,
    icon,
    iconColor,
    iconSize,
    parentIconSize,
    parentIconColor,
    border,
    center,
    reverse,
    direction,
    iconClassPrefix,
    iconFontClassName,
    onPress,
    ...rest
  } = {
    ...defaultProps,
    ...props
  };
  const [viewHeight, setViewHeight] = (0, _react.useState)(0);
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const mStyles = (0, _styles.default)(theme);
  const pxCheck = value => {
    let getValue = value;
    if (Number.isNaN(Number(value)) || typeof value === 'string') {
      getValue = parseInt(String(value));
    }
    if (!getValue || getValue == '') {
      getValue = 20;
    }
    return getValue;
  };
  const rootStyle = () => {
    const style = {
      flexBasis: `${100 / +columnNum}%`
    };
    if (gutter) {
      style.paddingRight = pxCheck(gutter);
      if (index >= columnNum) {
        style.marginTop = pxCheck(gutter);
      }
    }
    if (border) {
      if (index % parseInt(columnNum) !== parseInt(columnNum) - 1) {
        style.borderRightWidth = gutter;
        style.borderBottomWidth = gutter;
        style.borderColor = '#f2f2f2';
      } else {
        style.borderLeftWidth = 0;
        style.borderTopWidth = 0;
        style.borderBottomWidth = gutter;
        style.borderColor = '#f2f2f2';
      }
    }
    if (viewHeight != 0) {
      style.height = viewHeight;
    }
    return style;
  };
  const isIconName = () => {
    return typeof icon === 'string';
  };
  const isText = () => {
    return typeof text === 'string';
  };
  if (reverse) {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: [rootStyle(), mStyles.nut_grid_item_container, {
        flexDirection: direction === 'horizontal' ? 'row' : 'column'
      }],
      onLayout: event => {
        var _event$nativeEvent, _event$nativeEvent$la;
        if (viewHeight !== (event === null || event === void 0 ? void 0 : (_event$nativeEvent = event.nativeEvent) === null || _event$nativeEvent === void 0 ? void 0 : (_event$nativeEvent$la = _event$nativeEvent.layout) === null || _event$nativeEvent$la === void 0 ? void 0 : _event$nativeEvent$la.width) && square) {
          var _event$nativeEvent2, _event$nativeEvent2$l;
          setViewHeight(event === null || event === void 0 ? void 0 : (_event$nativeEvent2 = event.nativeEvent) === null || _event$nativeEvent2 === void 0 ? void 0 : (_event$nativeEvent2$l = _event$nativeEvent2.layout) === null || _event$nativeEvent2$l === void 0 ? void 0 : _event$nativeEvent2$l.width);
        }
      },
      onPress: onPress
    }, children && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children), text && text != '' && isText() ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: direction === 'horizontal' ? mStyles.nut_grid_item_right_text : mStyles.nut_grid_item_bottom_text
    }, text) : text === '' ? null : /*#__PURE__*/_react.default.createElement(_reactNative.View, null, text), icon && isIconName() ? /*#__PURE__*/_react.default.createElement(_index.default, {
      classPrefix: iconClassPrefix,
      fontClassName: iconFontClassName,
      name: icon,
      size: iconSize || parentIconSize,
      color: iconColor || parentIconColor ? iconColor || parentIconColor : undefined
    }) : icon && icon != '' ? /*#__PURE__*/_react.default.createElement(_reactNative.View, null, icon) : null);
  } else {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: [rootStyle(), mStyles.nut_grid_item_container, {
        flexDirection: direction === 'horizontal' ? 'row' : 'column'
      }],
      onLayout: event => {
        var _event$nativeEvent3, _event$nativeEvent3$l;
        if (viewHeight !== (event === null || event === void 0 ? void 0 : (_event$nativeEvent3 = event.nativeEvent) === null || _event$nativeEvent3 === void 0 ? void 0 : (_event$nativeEvent3$l = _event$nativeEvent3.layout) === null || _event$nativeEvent3$l === void 0 ? void 0 : _event$nativeEvent3$l.width) && square) {
          var _event$nativeEvent4, _event$nativeEvent4$l;
          setViewHeight(event === null || event === void 0 ? void 0 : (_event$nativeEvent4 = event.nativeEvent) === null || _event$nativeEvent4 === void 0 ? void 0 : (_event$nativeEvent4$l = _event$nativeEvent4.layout) === null || _event$nativeEvent4$l === void 0 ? void 0 : _event$nativeEvent4$l.width);
        }
      },
      onPress: onPress
    }, icon && isIconName() ? /*#__PURE__*/_react.default.createElement(_index.default, {
      classPrefix: iconClassPrefix,
      fontClassName: iconFontClassName,
      name: icon,
      size: iconSize || parentIconSize,
      color: iconColor || parentIconColor ? iconColor || parentIconColor : undefined
    }) : icon && icon != '' ? /*#__PURE__*/_react.default.createElement(_reactNative.View, null, icon) : null, text && text != '' && isText() ? /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: direction === 'horizontal' ? mStyles.nut_grid_item_left_text : mStyles.nut_grid_item_top_text
    }, text) : text === '' ? null : /*#__PURE__*/_react.default.createElement(_reactNative.View, null, text), children && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children));
  }
};
exports.GridItem = GridItem;
GridItem.defaultProps = defaultProps;
GridItem.displayName = 'NutGridItem';
//# sourceMappingURL=griditem.js.map