"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.InputNumber = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _index = _interopRequireDefault(require("../icon/index"));
var _typings = require("../utils/typings");
var _pt = _interopRequireDefault(require("../utils/pt"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const defaultProps = {
  ..._typings.ComponentDefaults,
  disabled: false,
  buttonSize: '',
  min: 1,
  max: 9999,
  inputWidth: '',
  readonly: false,
  modelValue: 0,
  step: 1,
  decimalPlaces: 0,
  isAsync: false
};
function pxCheck(value) {
  return value ? (0, _pt.default)(parseInt(`${value}`)) : 0;
}
const InputNumber = props => {
  const {
    children,
    disabled,
    buttonSize,
    min,
    max,
    inputWidth,
    readonly,
    modelValue,
    decimalPlaces,
    step,
    isAsync,
    className,
    style,
    onAdd,
    onReduce,
    onOverlimit,
    onBlurFuc,
    onFocus,
    onChangeFuc,
    iconClassPrefix,
    iconFontClassName,
    ...restProps
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const mStyles = (0, _styles.default)(theme);
  const [inputValue, setInputValue] = (0, _react.useState)(modelValue);
  (0, _react.useEffect)(() => {
    const outputValue = fixedDecimalPlaces(modelValue);
    setInputValue(outputValue);
  }, [modelValue]);
  const styles = {
    ...style
  };
  const addAllow = function () {
    let value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Number(inputValue);
    return value < Number(max) && !disabled;
  };
  const reduceAllow = function () {
    let value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Number(inputValue);
    return value > Number(min) && !disabled;
  };
  const fixedDecimalPlaces = v => {
    return Number(v).toFixed(Number(decimalPlaces));
  };
  const emitChange = (value, e) => {
    const outputValue = fixedDecimalPlaces(value);
    onChangeFuc && onChangeFuc(outputValue, e);
    if (!isAsync) {
      if (Number(outputValue) < Number(min)) {
        setInputValue(Number(min));
      } else if (Number(outputValue) > Number(max)) {
        setInputValue(Number(max));
      } else {
        setInputValue(outputValue);
      }
    }
  };
  const reduceNumber = e => {
    onReduce && onReduce(e);
    if (reduceAllow()) {
      const outputValue = Number(inputValue) - Number(step);
      emitChange(outputValue, e);
    } else {
      onOverlimit && onOverlimit(e);
    }
  };
  const addNumber = e => {
    onAdd && onAdd(e);
    if (addAllow()) {
      const outputValue = Number(inputValue) + Number(step);
      emitChange(outputValue, e);
    } else {
      onOverlimit && onOverlimit(e);
    }
  };
  const changeValue = e => {
    const value = Number(e === null || e === void 0 ? void 0 : e.nativeEvent.text);
    onChangeFuc && onChangeFuc(value, e);
    if (!isAsync) {
      if (Number.isNaN(value)) {
        setInputValue(inputValue);
      } else {
        setInputValue(value);
      }
    }
  };
  const focusValue = e => {
    if (disabled) return;
    if (readonly) return;
    onFocus && onFocus(e);
  };
  const burValue = e => {
    if (disabled) return;
    if (readonly) return;
    let value = Number(e === null || e === void 0 ? void 0 : e.nativeEvent.text);
    if (value < Number(min)) {
      value = Number(min);
    } else if (value > Number(max)) {
      value = Number(max);
    }
    emitChange(value, e);
    onBlurFuc && onBlurFuc(e);
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [styles, {
      flexDirection: 'row',
      alignItems: 'center',
      paddingVertical: (0, _pt.default)(10)
    }]
  }, restProps), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: reduceNumber
  }, /*#__PURE__*/_react.default.createElement(_index.default, {
    style: mStyles.nut_icon_marginH,
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    size: buttonSize,
    color: reduceAllow() ? "#2c2c2c" : "#bfbfbf",
    name: 'minus'
  })), _reactNative.Platform.OS === 'web' ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: pxCheck(inputWidth) == 0 ? mStyles.nut_inputnumber_zerowidth : {
      width: pxCheck(inputWidth),
      ...mStyles.nut_inputnumber_fixwidth
    }
  }, /*#__PURE__*/_react.default.createElement("input", {
    type: "number",
    min: min,
    max: max,
    style: {
      width: pxCheck(inputWidth) == 0 ? 50 : pxCheck(inputWidth),
      textAlign: 'center',
      borderWidth: 0,
      backgroundColor: 'transparent'
    },
    disabled: disabled,
    readOnly: readonly,
    value: inputValue,
    onInput: changeValue,
    onBlur: burValue,
    onFocus: focusValue
  })) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: pxCheck(inputWidth) == 0 ? mStyles.nut_inputnumber_zerowidth : {
      width: pxCheck(inputWidth),
      ...mStyles.nut_inputnumber_fixwidth
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    type: "number",
    min: min,
    max: max,
    style: {
      color: disabled ? '#d5d5d5' : '#000000',
      padding: 0
    },
    textAlign: "center",
    editable: !(readonly || disabled),
    value: `${inputValue}`,
    onChange: changeValue,
    onBlur: burValue,
    onFocus: focusValue
  })), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: addNumber
  }, /*#__PURE__*/_react.default.createElement(_index.default, {
    style: mStyles.nut_icon_marginH,
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    size: buttonSize,
    color: addAllow() ? "#2c2c2c" : "#bfbfbf",
    name: 'plus',
    onPress: addNumber
  })));
};
exports.InputNumber = InputNumber;
InputNumber.defaultProps = defaultProps;
InputNumber.displayName = 'NutInputNumber';
//# sourceMappingURL=inputnumber.js.map