"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var React = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _bg = _interopRequireDefault(require("./bg"));
var _color = require("../utils/color");
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _filterTextStyle = _interopRequireDefault(require("../utils/filter-text-style"));
var _styles = _interopRequireDefault(require("./styles"));
var _configprovider = require("../configprovider");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const {
  theme
} = (0, _configprovider.getDefaultConfig)();
const styles = (0, _styles.default)(theme);
class Notification extends React.PureComponent {
  constructor(props) {
    super(props);
    this.close = this.close.bind(this);
    this.startCloseTimer = this.startCloseTimer.bind(this);
    this.clearCloseTimer = this.clearCloseTimer.bind(this);
    this.clickCover = this.clickCover.bind(this);
    this.state = {
      show: true,
      fadeAnim: new _reactNative.Animated.Value(0)
    };
  }
  close() {
    let {
      onAnimationEnd,
      onClosed
    } = this.props;
    this.setState({
      show: false
    });
    this.clearCloseTimer();
    onAnimationEnd && onAnimationEnd();
    onClosed && onClosed();
  }
  startCloseTimer() {
    const {
      duration
    } = this.props;
    if (duration) {
      this.closeTimer = window.setTimeout(() => {
        this.close();
      }, duration);
    }
  }
  clearCloseTimer() {
    if (this.closeTimer) {
      clearTimeout(this.closeTimer);
      this.closeTimer = -1;
    }
  }
  clickCover() {
    this.props.onPress();
  }
  componentDidMount() {
    this.startCloseTimer();
    let {
      onAnimationEnd
    } = this.props;
    const duration = this.props.duration;
    const timing = _reactNative.Animated.timing;
    if (this.anim) {
      this.anim = null;
    }
    const animArr = [timing(this.state.fadeAnim, {
      toValue: 1,
      duration: 200,
      useNativeDriver: true
    }), _reactNative.Animated.delay(duration)];
    if (duration > 0) {
      animArr.push(timing(this.state.fadeAnim, {
        toValue: 0,
        duration: 200,
        useNativeDriver: true
      }));
    }
    this.anim = _reactNative.Animated.sequence(animArr);
    this.anim.start(() => {
      if (duration > 0) {
        this.anim = null;
        if (onAnimationEnd) {
          onAnimationEnd();
        }
      }
    });
  }
  componentWillUnmount() {
    this.clearCloseTimer();
    if (this.anim) {
      this.anim.stop();
      this.anim = null;
    }
  }
  getBgByButtonType = type => {
    const objStyle = {
      start: {
        x: 0,
        y: 0
      },
      end: {
        x: 1,
        y: 0
      }
    };
    if (type === 'base') {
      return {
        ...objStyle,
        useAngle: true,
        angle: 135,
        locations: [0, 0.45, 0.83, 1],
        colors: theme['$notify-base-background-color']
      };
    } else if (type === 'primary') {
      return {
        ...objStyle,
        useAngle: true,
        angle: 315,
        locations: [0, 1],
        colors: theme['$notify-primary-background-color']
      };
    } else if (type === 'success') {
      return {
        ...objStyle,
        useAngle: true,
        angle: 135,
        locations: [0, 0.45, 0.83, 1],
        colors: theme['$notify-success-background-color']
      };
    } else if (type === 'warning') {
      return {
        ...objStyle,
        useAngle: true,
        angle: 135,
        locations: [0, 1],
        colors: theme['$notify-warning-background-color']
      };
    } else if (type === 'danger') {
      return {
        locations: [],
        colors: []
      };
    }
    return {
      locations: [],
      colors: []
    };
  };
  getBgStyle = () => {
    let {
      type
    } = this.props;
    return this.getBgByButtonType(type);
  };
  renderChildren = () => {
    let {
      children,
      style,
      message,
      color
    } = this.props;
    let textStyle = [styles.text, color ? {
      color
    } : {}, (0, _filterTextStyle.default)((0, _styleToObj.default)(style || {}))];
    if (typeof children === 'string') {
      return /*#__PURE__*/React.createElement(_reactNative.Text, {
        style: textStyle
      }, children);
    }
    if (children) {
      return children;
    }
    return /*#__PURE__*/React.createElement(_reactNative.Text, {
      style: textStyle
    }, message);
  };
  render() {
    const {
      style,
      backgroundColor,
      type,
      position
    } = this.props;
    const {
      fadeAnim
    } = this.state;
    console.log('props', this.context);
    let wrapStyle = [styles.container, styles[`containerPosition${position}`], styles[`containerType${type}`], (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {})), backgroundColor && !(0, _color.isLinearGradient)(backgroundColor) ? {
      backgroundColor: backgroundColor
    } : {}, {
      opacity: fadeAnim
    }];
    const innerStyle = [styles.container, styles[`containerPosition${position}`], styles[`containerType${type}`], (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {})), backgroundColor && !(0, _color.isLinearGradient)(backgroundColor) ? {
      backgroundColor: backgroundColor
    } : {}];
    return /*#__PURE__*/React.createElement(_reactNative.Animated.View, {
      style: wrapStyle
    }, /*#__PURE__*/React.createElement(_bg.default, _extends({
      style: innerStyle
    }, this.getBgStyle(), {
      type: type,
      color: backgroundColor
    }), this.renderChildren()));
  }
}
exports.default = Notification;
Notification.newInstance = (properties, callback) => {
  const id = properties.id ? properties.id : `${new Date().getTime()}`;
  let called = false;
  const ref = instance => {
    if (called) {
      return;
    }
    called = true;
    callback({
      component: instance,
      destroy() {}
    });
  };
  ref(void 0);
};
//# sourceMappingURL=notification.js.map