"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultOverlayProps = exports.Overlay = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultOverlayProps = {
  zIndex: 2000,
  duration: 0.3,
  overlayClass: '',
  closeOnClickOverlay: true,
  visible: false,
  overlayStyle: {},
  onPress: () => {}
};
exports.defaultOverlayProps = defaultOverlayProps;
const Overlay = props => {
  const {
    children,
    zIndex,
    duration,
    overlayClass,
    closeOnClickOverlay,
    visible,
    overlayStyle,
    onPress,
    ...rest
  } = {
    ...defaultOverlayProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const mStyles = (0, _styles.default)(theme);
  const [show, setShow] = (0, _react.useState)(visible);
  (0, _react.useEffect)(() => {
    visible && setShow(visible);
  }, [visible]);
  const styles = {
    zIndex,
    ...overlayStyle
  };
  const handleClick = e => {
    if (closeOnClickOverlay) {
      props.onPress && props.onPress(e);
      const id = setTimeout(() => {
        setShow(!show);
      }, duration * 1000 * 0.8);
    }
  };
  const animatedValue = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  _reactNative.Animated.timing(animatedValue, {
    toValue: visible ? 1 : 0,
    duration: duration * 1000,
    easing: _reactNative.Easing.ease,
    useNativeDriver: true
  }).start();
  return /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
    animationType: "none",
    transparent: true,
    visible: show
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [mStyles.nut_overlay_full, {
      opacity: animatedValue,
      ...styles
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: handleClick,
    activeOpacity: 1,
    style: [mStyles.nut_overlay_full_bg, {
      ...styles
    }]
  }, children)));
};
exports.Overlay = Overlay;
Overlay.defaultProps = defaultOverlayProps;
Overlay.displayName = 'NutOverlay';
//# sourceMappingURL=overlay.js.map