"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Popup = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _index = _interopRequireDefault(require("../icon/index"));
var _typings = require("../utils/typings");
var _deviceWidth = _interopRequireDefault(require("../utils/deviceWidth"));
var _deviceHeight = _interopRequireDefault(require("../utils/deviceHeight"));
var _statusBarHeight = _interopRequireDefault(require("../utils/statusBarHeight"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  ..._typings.ComponentDefaults,
  position: 'center',
  style: {},
  closeable: false,
  closeIconPosition: 'top-right',
  closeIcon: 'close',
  destroyOnClose: true,
  overlay: true,
  round: false,
  onOpen: () => {},
  onClose: () => {},
  onClick: e => {},
  onOpened: e => {},
  onClosed: e => {},
  onClickOverlay: e => {},
  onClickCloseIcon: e => {}
  //...defaultOverlayProps,
};

let _zIndex = 2000;
const Popup = props => {
  const {
    children,
    visible,
    overlay,
    closeOnClickOverlay,
    overlayStyle,
    zIndex,
    duration,
    closeable,
    closeIconPosition,
    closeIcon,
    style,
    round,
    position,
    destroyOnClose,
    onOpen,
    onClose,
    onClickOverlay,
    onClickCloseIcon,
    onOpened,
    onClosed,
    onClick
  } = props;
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const mStyles = (0, _styles.default)(theme);
  const [index, setIndex] = (0, _react.useState)(zIndex || _zIndex);
  const [innerVisible, setInnerVisible] = (0, _react.useState)(visible);
  const [showChildren, setShowChildren] = (0, _react.useState)(true);
  const [viewWidth, setViewWidth] = (0, _react.useState)(0);
  const baseStyle = {
    zIndex: index
  };
  const overlayStyles = {
    ...overlayStyle,
    ...baseStyle
  };
  const popStyles = {
    ...style,
    ...baseStyle
  };
  const open = () => {
    if (!innerVisible) {
      setInnerVisible(true);
      setIndex(++_zIndex);
    }
    if (destroyOnClose) {
      setShowChildren(true);
    }
    onOpen && onOpen();
  };
  const close = () => {
    if (innerVisible) {
      setInnerVisible(false);
      if (destroyOnClose) {
        setShowChildren(false);
        onClose && onClose();
      }
    }
  };
  const onHandleClickOverlay = e => {
    if (closeOnClickOverlay) {
      onClickOverlay && onClickOverlay(e);
      close();
    }
  };
  const onHandleClick = e => {
    onClose && onClose();
  };
  const onHandleClickCloseIcon = e => {
    onClickCloseIcon && onClickCloseIcon(e);
    close();
  };
  const animatedValue = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  _reactNative.Animated.timing(animatedValue, {
    toValue: innerVisible ? 1 : 0,
    duration: duration ? duration * 1000 : 300,
    easing: _reactNative.Easing.ease,
    useNativeDriver: true
  }).start();
  const getStyles = () => {
    let styles = {};
    switch (position) {
      case 'top':
        if (round) {
          styles = mStyles.nut_pop_top_radius;
        } else {
          styles = mStyles.nut_pop_top;
        }
        break;
      case 'center':
        if (round) {
          styles = {
            top: (_deviceHeight.default - (_statusBarHeight.default ? _statusBarHeight.default : 0)) / 2 - (popStyles !== null && popStyles !== void 0 && popStyles.paddingTop ? parseInt(String(popStyles.paddingTop)) : 0),
            left: (_deviceWidth.default - viewWidth) / 2,
            borderRadius: 15
          };
        } else {
          styles = {
            top: (_deviceHeight.default - (_statusBarHeight.default ? _statusBarHeight.default : 0)) / 2 - (popStyles !== null && popStyles !== void 0 && popStyles.paddingTop ? parseInt(String(popStyles.paddingTop)) : 0),
            left: (_deviceWidth.default - viewWidth) / 2
          };
        }
        break;
      case 'bottom':
        if (round) {
          styles = mStyles.nut_pop_bottom_radius;
        } else {
          styles = mStyles.nut_pop_bottom;
        }
        break;
      case 'right':
        styles = mStyles.nut_pop_right;
        break;
      case 'left':
        styles = mStyles.nut_pop_left;
        break;
      default:
        break;
    }
    return styles;
  };
  const getIconStyles = () => {
    let styles = {};
    switch (closeIconPosition) {
      case 'top-left':
        styles = mStyles.nut_icon_top_left;
        break;
      case 'top-right':
        styles = mStyles.nut_icon_top_right;
        break;
      case 'bottom-left':
        styles = mStyles.nut_icon_bottom_left;
        break;
      case 'bottom-right':
        styles = mStyles.nut_icon_bottom_right;
        break;
      default:
        break;
    }
    return styles;
  };
  const renderPop = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      style: {
        position: 'absolute',
        opacity: animatedValue,
        overflow: 'hidden',
        ...popStyles,
        ...getStyles()
      }
    }, showChildren ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        flex: 1
      },
      onLayout: event => {
        if (position === 'center' && viewWidth === 0) {
          var _event$nativeEvent, _event$nativeEvent$la;
          setViewWidth(event === null || event === void 0 ? void 0 : (_event$nativeEvent = event.nativeEvent) === null || _event$nativeEvent === void 0 ? void 0 : (_event$nativeEvent$la = _event$nativeEvent.layout) === null || _event$nativeEvent$la === void 0 ? void 0 : _event$nativeEvent$la.width);
        }
      }
    }, children) : null, closeable ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: {
        position: 'absolute',
        ...getIconStyles()
      },
      onPress: e => {
        onClickCloseIcon && onClickCloseIcon(e);
      }
    }, /*#__PURE__*/_react.default.createElement(_index.default, {
      onPress: onHandleClickCloseIcon,
      name: closeIcon,
      size: "18"
    })) : null);
  };
  const renderNode = () => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
      visible: visible,
      transparent: true,
      animationType: "none",
      onRequestClose: onHandleClick
    }, overlay ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: mStyles.nut_pop_full,
      activeOpacity: 1,
      onPress: onHandleClickOverlay
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: mStyles.nut_popbg_full
    })), renderPop()) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, renderPop()));
  };
  (0, _react.useEffect)(() => {
    visible && open();
    !visible && close();
  }, [visible]);
  return renderNode();
};
exports.Popup = Popup;
Popup.defaultProps = defaultProps;
Popup.displayName = 'NutPopup';
//# sourceMappingURL=popup.js.map