"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Progress = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _icon = _interopRequireDefault(require("../icon"));
var _typings = require("../utils/typings");
var _pt = _interopRequireDefault(require("../utils/pt"));
var LinearGradient = _interopRequireWildcard(require("react-native-linear-gradient"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const defaultProps = {
  ..._typings.ComponentDefaults,
  className: '',
  style: {},
  isShowPercentage: true,
  percentage: 0,
  fillColor: '#f3f3f3',
  strokeColor: ['#fa2c19', '#fa6419'],
  strokeWidth: '10',
  textColor: '',
  textWidth: '',
  showText: true,
  textInside: false,
  textBackground: ['#fa2c19', '#fa6419'],
  textType: 'text',
  status: false,
  iconName: 'checked',
  iconColor: '#439422',
  iconSize: '16px',
  children: undefined
};
const Progress = props => {
  const [proWidth, setProWidth] = (0, _react.useState)(0);
  const [proHeight, setProHeight] = (0, _react.useState)(0);
  const [proInnerWidth, setProInnerWidth] = (0, _react.useState)(0);
  const [proInnerHeight, setProInnerHeight] = (0, _react.useState)(0);
  const animationRef = (0, _react.useRef)(new _reactNative.Animated.Value(0));
  const animationRefTag = (0, _react.useRef)(new _reactNative.Animated.Value(0));
  const {
    className,
    style,
    isShowPercentage,
    percentage,
    fillColor,
    strokeColor,
    strokeWidth,
    size,
    textColor,
    textWidth,
    showText,
    textInside,
    textBackground,
    textType,
    status,
    iconName,
    iconColor,
    iconSize,
    children,
    iconClassPrefix,
    iconFontClassName,
    ...rest
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  (0, _react.useEffect)(() => {
    //setValue(props.value)
    startAnimated();
  }, [props.percentage, proWidth]);
  const startAnimated = () => {
    _reactNative.Animated.timing(animationRef.current, {
      toValue: parseInt(props.percentage / 100 * proWidth),
      duration: 800,
      useNativeDriver: false
    }).start();

    //let leftV = 0;
    _reactNative.Animated.timing(animationRefTag.current, {
      toValue: parseInt(props.percentage / 100 * proWidth) - proInnerWidth / 2,
      duration: 800,
      useNativeDriver: false
    }).start();
  };
  const getHeight = () => {
    let height;
    switch (size) {
      case 'small':
        height = (0, _pt.default)(12);
        break;
      case 'base':
        height = (0, _pt.default)(20);
        break;
      case 'large':
        height = (0, _pt.default)(30);
        break;
      default:
        height = parseInt(strokeWidth);
        break;
    }
    return height;
  };

  //hex -> rgba
  const hexToRgba = (hex, opacity) => {
    return 'rgba(' + parseInt('0x' + hex.slice(1, 3)) + ',' + parseInt('0x' + hex.slice(3, 5)) + ',' + parseInt('0x' + hex.slice(5, 7)) + ',' + opacity + ')';
  };
  const LinearGradientModuleRef = LinearGradient;
  const LinearGradientComponent = LinearGradientModuleRef.LinearGradient || LinearGradientModuleRef.default;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [styles.containerOut, style]
  }, rest), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.containerInner
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.progressBg, {
      backgroundColor: fillColor || '#f3f3f3',
      height: getHeight(),
      borderRadius: getHeight() / 2
    }],
    onLayout: e => {
      setProWidth(e.nativeEvent.layout.width);
      setProHeight(e.nativeEvent.layout.height);
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: {
      width: animationRef.current,
      height: getHeight()
    }
  }, _reactNative.Platform.OS === 'web' ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flex: 1,
      height: getHeight(),
      borderRadius: getHeight() / 2,
      background: `linear-gradient(90deg, ${hexToRgba(strokeColor[0], 1)} 0%,${hexToRgba(strokeColor[1], 1)} 100%)`
    }
  }) : /*#__PURE__*/_react.default.createElement(LinearGradientComponent, {
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    },
    colors: strokeColor,
    style: {
      flex: 1,
      height: getHeight(),
      borderRadius: getHeight() / 2
    }
  })), showText && textInside && /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: {
      position: 'absolute',
      marginLeft: animationRef.current,
      left: -proInnerWidth / 2,
      top: -((proInnerHeight - proHeight) / 2),
      marginBottom: 'auto',
      marginTop: 'auto'
    },
    onLayout: e => {
      setProInnerWidth(e.nativeEvent.layout.width);
      setProInnerHeight(e.nativeEvent.layout.height);
    }
  }, textType === 'icon' ? /*#__PURE__*/_react.default.createElement(_icon.default, {
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    size: iconSize,
    name: iconName,
    color: iconColor
  }) : /*#__PURE__*/_react.default.createElement(LinearGradientComponent, {
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    },
    colors: textBackground,
    style: styles.progreessTg
  }, textType === 'text' && /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      color: textColor || '#333'
    }
  }, percentage, isShowPercentage ? '%' : '')), _reactNative.Platform.OS === 'web' ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.progreessTg, {
      background: `linear-gradient(90deg, ${hexToRgba(textBackground[0], 1)} 0%,${hexToRgba(textBackground[1], 1)} 100%)`
    }]
  }, textType === 'text' && /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      color: textColor || '#333'
    }
  }, percentage, isShowPercentage ? '%' : '')) : /*#__PURE__*/_react.default.createElement(LinearGradientComponent, {
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    },
    colors: textBackground,
    style: styles.progreessTg
  }, textType === 'text' && /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      color: textColor || '#333'
    }
  }, percentage, isShowPercentage ? '%' : '')))), showText && !textInside && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children ? /*#__PURE__*/_react.default.createElement(_reactNative.View, null, children) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      color: textColor || '#000'
    }
  }, percentage, isShowPercentage ? '%' : '')))));
};
exports.Progress = Progress;
Progress.defaultProps = defaultProps;
Progress.displayName = 'NutProgress';
//# sourceMappingURL=progress.js.map