"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Skeleton = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _avatar = _interopRequireDefault(require("../avatar"));
var LinearGradient = _interopRequireWildcard(require("react-native-linear-gradient"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _pt = _interopRequireDefault(require("../utils/pt"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  width: 100,
  height: 100,
  row: 1,
  animated: false,
  title: false,
  avatar: false,
  round: false,
  avatarSize: 50,
  loading: false,
  avatarShape: 'round'
};
const Skeleton = props => {
  const {
    width,
    height,
    animated,
    row,
    title,
    avatar,
    avatarSize,
    style,
    round,
    loading,
    children,
    avatarShape
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const animationRef = (0, _react.useRef)(new _reactNative.Animated.Value(0));
  const animationLoop = (0, _react.useRef)();
  const [layoutWidth, setLayoutWidth] = _react.default.useState(0);
  const repeatLines = num => {
    return Array.from({
      length: num
    }, (v, i) => i);
  };
  (0, _react.useEffect)(() => {
    animationLoop.current = _reactNative.Animated.timing(animationRef.current, {
      toValue: 2,
      delay: 400,
      duration: 1500,
      useNativeDriver: !!_reactNative.Platform.select({
        web: false,
        native: true
      })
    });
    animationRef.current.setValue(0);
    _reactNative.Animated.loop(animationLoop.current).start();
  }, []);
  const getStyle = () => {
    if (avatarSize) {
      return {
        width: avatarSize,
        height: avatarSize
      };
    }
    return {
      width: 50,
      height: 50
    };
  };
  const wrapStyle = [styles.container, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {}))];
  const blockStyle = [styles.blockStyle, round ? styles.blockRoundStyle : {}, {
    width,
    height
  }];
  const avatarStyle = [styles.avatarStyle, getStyle()];
  const LinearGradientModuleRef = LinearGradient;
  const LinearGradientComponent = LinearGradientModuleRef.LinearGradient || LinearGradientModuleRef.default;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, loading ? /*#__PURE__*/_react.default.createElement(_reactNative.View, null, children) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle,
    onLayout: _ref => {
      let {
        nativeEvent
      } = _ref;
      setLayoutWidth(nativeEvent.layout.width);
    }
  }, animated ? /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.skeletonAnimation, {
      height: height * row,
      width: width / 4
    }, {
      transform: [{
        translateX: animationRef.current.interpolate({
          inputRange: [0, 1],
          outputRange: [-width / 4, width]
        })
      }]
    }]
  }, /*#__PURE__*/_react.default.createElement(LinearGradientComponent, {
    style: {
      height: height * row + (row > 1 ? row * (0, _pt.default)(20) : 0) + (title ? (0, _pt.default)(30) : 0)
    },
    colors: ['rgba(255,255,255,0.3)', 'rgba(255,255,255,0.5)', 'rgba(255,255,255,0.3)'],
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    }
  })) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.nutSkeletonContent
  }, avatar && /*#__PURE__*/_react.default.createElement(_avatar.default, {
    style: avatarStyle,
    bgColor: "rgb(239, 239, 239)",
    shape: avatarShape
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.skeletonContentLine
  }, title && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.skeletonTitle
  }), repeatLines(row).map((item, index) => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: blockStyle,
      key: +index
    });
  })))));
};
exports.Skeleton = Skeleton;
Skeleton.defaultProps = defaultProps;
Skeleton.displayName = 'NutSkeleton';
//# sourceMappingURL=skeleton.js.map