"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Swiper = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _userContext = require("./userContext");
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _pageview = _interopRequireDefault(require("./pageview"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  width: 375,
  height: 0,
  duration: 500,
  initPage: 0,
  autoPlay: 0,
  direction: 'horizontal',
  paginationColor: '#fff',
  paginationBgColor: '#d3d3d3',
  paginationVisible: false,
  loop: true,
  touchable: true,
  isCenter: false
};
const Swiper = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const propSwiper = {
    ...defaultProps,
    ...props
  };
  const {
    width,
    height,
    children,
    direction,
    loop,
    pageContent,
    onChange,
    initPage,
    paginationColor,
    paginationBgColor,
    paginationVisible,
    touchable,
    autoPlay,
    isCenter,
    style
  } = propSwiper;
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const pageViewRef = (0, _react.useRef)(null);
  const isVertical = direction === 'vertical';
  const size = isVertical ? height : width;
  const {
    childs,
    childCount
  } = (0, _react.useMemo)(() => {
    let childCount = 0;
    const childs = _react.default.Children.map(children, child => {
      if (! /*#__PURE__*/_react.default.isValidElement(child)) return null;
      childCount++;
      return child;
    });
    return {
      childs,
      childCount
    };
  }, [children]);
  // 父组件参数传入子组件item
  const parent = {
    propSwiper,
    size
  };
  const itemStyle2 = () => {
    const styleObj = {};
    if (size) {
      if (direction === 'horizontal') {
        styleObj.width = size;
      } else {
        styleObj.height = size;
      }
    }
    return styleObj;
  };
  const to = index => {
    const target = pageViewRef.current;
    target.goTo(index);
  };

  // 下一页
  const next = () => {
    const target = pageViewRef.current;
    target.scrollNextPage();
  };
  const prev = () => {
    const target = pageViewRef.current;
    target.goPrev();
  };
  _react.default.useImperativeHandle(ref, () => ({
    to,
    next,
    prev
  }));
  const itemStyle = [styles.itemStyle, itemStyle2()];
  const wrapStyle = [(0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {}))];
  return /*#__PURE__*/_react.default.createElement(_userContext.DataContext.Provider, {
    value: parent
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, childCount > 0 ? /*#__PURE__*/_react.default.createElement(_pageview.default, {
    ref: pageViewRef,
    style: {
      width: width || '100%',
      height: height
    },
    styles: styles,
    vertical: isVertical,
    autoplay: autoPlay > 0,
    autoplayInterval: autoPlay || 0,
    infinite: loop,
    selectedIndex: initPage,
    dotStyle: {
      backgroundColor: paginationBgColor
    },
    dotActiveStyle: {
      backgroundColor: paginationColor
    },
    afterChange: onChange,
    dots: paginationVisible || !!pageContent,
    pagination: pageContent ? () => {
      return pageContent;
    } : undefined
  }, _react.default.Children.map(childs, (child, index) => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: itemStyle,
      key: index
    }, child);
  })) : null));
});
exports.Swiper = Swiper;
Swiper.defaultProps = defaultProps;
Swiper.displayName = 'NutSwiper';
//# sourceMappingURL=swiper.js.map