"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Switch = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _button = _interopRequireDefault(require("./button"));
var _pt = _interopRequireDefault(require("../utils/pt"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
var _useAnimations = require("./useAnimations");
var _view = _interopRequireDefault(require("./view"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  isAsync: false,
  checked: false,
  disable: false,
  activeColor: '',
  inactiveColor: '',
  activeText: '',
  inactiveText: ''
};
const AnimatedView = _reactNative.Animated.createAnimatedComponent(_view.default);
const Switch = props => {
  const {
    isAsync,
    checked,
    disable,
    activeColor,
    inactiveColor,
    activeText,
    inactiveText,
    onChange,
    style
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  const checkedRef = _react.default.useRef();
  if (checkedRef.current === undefined) {
    checkedRef.current = checked;
  }
  const [innerChecked, setInnerChecked] = (0, _react.useState)(checkedRef.current);
  (0, _react.useEffect)(() => {
    checkedRef.current = checked;
    animate({
      toValue: checked ? 1 : 0
    });
    setInnerChecked(checked);
  }, [checked]);

  // animate1
  const [animatedValue, animate] = (0, _useAnimations.useAnimatedTiming)();
  const transitionMargin = {
    marginLeft: animatedValue.interpolate({
      inputRange: [0, 1],
      outputRange: [(0, _pt.default)(38), (0, _pt.default)(10)]
    }),
    marginRight: animatedValue.interpolate({
      inputRange: [0, 1],
      outputRange: [(0, _pt.default)(10), (0, _pt.default)(28)]
    })
  };

  // animate2
  const [animatedValue2, animate2] = (0, _useAnimations.useAnimatedTiming)();
  const transitionWidth = {
    width: animatedValue2.interpolate({
      inputRange: [0, 1],
      outputRange: [(0, _pt.default)(26), (0, _pt.default)(26)]
    }),
    left: !innerChecked ? animatedValue.interpolate({
      inputRange: [0, 1],
      outputRange: [(0, _pt.default)(8), 0]
    }) : undefined,
    right: innerChecked ? animatedValue.interpolate({
      inputRange: [0, 1],
      outputRange: [0, (0, _pt.default)(8)]
    }) : (0, _pt.default)(8)
  };

  // initial animate
  _react.default.useEffect(() => {
    if (innerChecked) {
      animate({});
      animate2({
        toValue: 0
      });
    } else {
      animate({
        toValue: 0
      });
    }
  }, [animate, animate2, innerChecked]);
  const triggerChange = (newChecked, event) => {
    if (!disable) {
      checkedRef.current = newChecked;
      if (!isAsync) {
        setInnerChecked(newChecked);
        onChange && onChange(newChecked, event);
        animate({
          toValue: newChecked ? 1 : 0
        });
      } else {
        onChange && onChange(newChecked, event);
      }
    }
  };
  const onPress = event => {
    triggerChange(!innerChecked, event);
  };
  const wrapStyle = [styles.container, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {})), styles[`disable${disable}`]];
  const innerStyle = [styles.innerStyle, innerChecked ? {
    backgroundColor: activeColor || theme['$primary-color']
  } : {
    backgroundColor: inactiveColor || theme['$switch-close-bg-color']
  }];
  const accessibilityState = {
    checked: innerChecked,
    disabled: disable
  };
  const switchStyle = [styles.switchHandle, styles[`switchHandleChecked${innerChecked}`], transitionWidth];
  const switchInnerStyle = [styles.switchInner, styles[`inner${innerChecked}`], transitionMargin];
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    accessibilityRole: "switch",
    accessibilityState: accessibilityState,
    style: wrapStyle
  }, /*#__PURE__*/_react.default.createElement(_button.default, {
    disabled: disable,
    onPress: onPress
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: innerStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: switchStyle
  }, !innerChecked ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.line
  }) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null)), /*#__PURE__*/_react.default.createElement(AnimatedView, {
    style: switchInnerStyle
  }, innerChecked ? activeText : inactiveText))));
};
exports.Switch = Switch;
Switch.defaultProps = defaultProps;
Switch.displayName = 'NutSwitch';
//# sourceMappingURL=switch.js.map