"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Table = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _icon = _interopRequireDefault(require("../icon"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _configprovider = require("../configprovider");
var _styles = _interopRequireDefault(require("./styles"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const defaultProps = {
  style: {},
  columns: [],
  data: [],
  bordered: true,
  striped: false,
  noData: '暂无数据'
};
const Table = props => {
  const {
    locale,
    theme
  } = (0, _configprovider.useConfig)();
  const styles = (0, _styles.default)(theme);
  defaultProps.noData = locale.noData;
  const {
    style,
    columns,
    data,
    bordered,
    summary,
    striped,
    noData,
    onSorter
  } = {
    ...defaultProps,
    ...props
  };
  const [curData, setCurData] = (0, _react.useState)(data);
  (0, _react.useEffect)(() => {
    if (data && String(data) !== String(curData)) {
      setCurData(data);
    }
  }, [data]);
  const handleSorterClick = item => {
    if (item.sorter) {
      onSorter && onSorter(item, curData);
      if (typeof item.sorter === 'function') {
        setCurData(curData.sort(item.sorter));
      } else {
        setCurData(item.sorter === 'default' ? curData.sort() : curData);
      }
    }
  };
  const cellClasses = item => {
    return [props.bordered ? styles.trBorder : {}, item.align ? styles[`trAlign${item.align}`] : {}];
  };
  const getColumnItem = value => {
    return columns.filter(item => item.key === value)[0];
  };
  const renderHeadCells = () => {
    return columns.map((item, index) => {
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: [styles.mainHeadTh, ...cellClasses(item), index === columns.length - 1 && bordered ? styles.rightBorder : {}],
        key: item.key,
        onTouchStart: () => {
          if (item.sorter) {
            handleSorterClick(item);
          }
        }
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: styles.title
      }, item.title), item.sorter ? /*#__PURE__*/_react.default.createElement(_icon.default, {
        name: "down-arrow",
        size: 12
      }) : null);
    });
  };
  const sortDataItem = () => {
    return columns.map(columns => {
      return [columns.key, columns.render];
    });
  };
  const renderBodyTds = item => {
    return sortDataItem().map((_ref, index) => {
      let [value, render] = _ref;
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: [styles.trtd, ...cellClasses(getColumnItem(value)), index === sortDataItem().length - 1 && bordered ? styles.rightBorder : {}],
        key: value
      }, typeof item[value] === 'function' || typeof render === 'function' ? render ? render(item) : item[value](item) : /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, item[value]));
    });
  };
  const renderBoyTrs = () => {
    return curData === null || curData === void 0 ? void 0 : curData.map((item, index) => {
      return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: [styles.mainBodyTr, index % 2 === 1 && striped ? {
          backgroundColor: '#f4f4f4'
        } : {}],
        key: index
      }, renderBodyTds(item));
    });
  };
  const wrapStyle = [styles.container, bordered ? styles.tableBorder : {}, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {}))];
  const mainStyle = [styles.mainStyle, striped ? styles.mainStriped : {}];
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: wrapStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: mainStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.mainHead
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.mainHeadTr, striped ? {
      backgroundColor: '#f4f4f4'
    } : {}]
  }, renderHeadCells())), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.mainBody
  }, renderBoyTrs())), summary ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.summary
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.summaryText
  }, summary)) : null, curData.length === 0 ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.nodata
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: styles.nodataText
  }, noData)) : null);
};
exports.Table = Table;
Table.defaultProps = defaultProps;
Table.displayName = 'NutTable';
//# sourceMappingURL=table.js.map