"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var React = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _pt = _interopRequireDefault(require("../utils/pt"));
var _icon = _interopRequireDefault(require("../icon"));
var _styleToObj = _interopRequireDefault(require("../utils/style-to-obj"));
var _filterContainerStyle = _interopRequireDefault(require("../utils/filter-container-style"));
var _filterTextStyle = _interopRequireDefault(require("../utils/filter-text-style"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
class Notification extends React.PureComponent {
  state = {
    fadeAnim: new _reactNative.Animated.Value(0)
  };
  close = () => {
    const {
      onClose,
      onAnimationEnd
    } = this.props;
    this.clearCloseTimer();
    onClose();
    onAnimationEnd && onAnimationEnd();
  };
  startCloseTimer = () => {
    const {
      duration
    } = this.props;
    if (duration) {
      this.closeTimer = setTimeout(() => {
        this.close();
      }, duration * 1000);
    }
  };
  clearCloseTimer = () => {
    if (this.closeTimer) {
      clearTimeout(this.closeTimer);
      this.closeTimer = -1;
    }
  };
  clickCover = () => {
    const {
      closeOnClickOverlay
    } = this.props;
    if (closeOnClickOverlay) {
      this.close();
    }
  };
  componentDidMount() {
    this.startCloseTimer();
    const {
      onAnimationEnd
    } = this.props;
    const duration = this.props.duration;
    const timing = _reactNative.Animated.timing;
    if (this.anim) {
      this.anim = null;
    }
    const animArr = [timing(this.state.fadeAnim, {
      toValue: 1,
      duration: 200,
      useNativeDriver: true
    }), _reactNative.Animated.delay(duration)];
    if (duration > 0) {
      animArr.push(timing(this.state.fadeAnim, {
        toValue: 0,
        duration: 200,
        useNativeDriver: true
      }));
    }
    this.anim = _reactNative.Animated.sequence(animArr);
    this.anim.start(() => {
      if (duration > 0) {
        this.anim = null;
        if (onAnimationEnd) {
          onAnimationEnd();
        }
      }
    });
  }
  componentWillUnmount() {
    this.clearCloseTimer();
    if (this.anim) {
      this.anim.stop();
      this.anim = null;
    }
  }
  renderContent = () => {
    const {
      bgColor,
      icon,
      style,
      iconSize,
      title,
      textAlignCenter,
      msg,
      size
    } = this.props;
    const {
      fadeAnim
    } = this.state;
    const innerStyle = [styles.innerContainer, {
      backgroundColor: bgColor
    }, {
      opacity: fadeAnim
    }];
    const textStyle = [styles.title, (0, _filterTextStyle.default)((0, _styleToObj.default)(style || {})), styles[`textAlign${textAlignCenter}`], styles[`textSize${size}`]];
    return /*#__PURE__*/React.createElement(_reactNative.Animated.View, {
      style: innerStyle
    }, icon ? /*#__PURE__*/React.createElement(_reactNative.View, {
      style: styles.iconContainer
    }, /*#__PURE__*/React.createElement(_icon.default, {
      name: icon || '',
      color: "#ffffff",
      size: iconSize
    })) : null, title ? /*#__PURE__*/React.createElement(_reactNative.Text, {
      style: textStyle
    }, title) : null, msg ? /*#__PURE__*/React.createElement(_reactNative.Text, {
      style: textStyle
    }, msg) : null);
  };
  render() {
    const {
      id,
      style,
      center,
      coverColor,
      cover,
      bottom,
      closeOnClickOverlay
    } = this.props;
    const wrapStyle = [styles.container, styles[`containerCenter${center}`], !center ? {
      bottom
    } : {}, (0, _filterContainerStyle.default)((0, _styleToObj.default)(style || {})), cover ? {
      backgroundColor: coverColor
    } : {}];
    if (closeOnClickOverlay) {
      return /*#__PURE__*/React.createElement(_reactNative.TouchableHighlight, {
        underlayColor: null,
        activeOpacity: 1,
        style: wrapStyle,
        onPress: this.clickCover
      }, /*#__PURE__*/React.createElement(_reactNative.TouchableHighlight, {
        underlayColor: null,
        activeOpacity: 1
      }, /*#__PURE__*/React.createElement(_reactNative.View, {
        key: `toast-${id}`
      }, this.renderContent())));
    }
    return /*#__PURE__*/React.createElement(_reactNative.View, {
      style: wrapStyle
    }, this.renderContent());
  }
}
exports.default = Notification;
Notification.newInstance = (properties, callback) => {
  let called = false;
  function ref(instance) {
    if (called) {
      return;
    }
    called = true;
    // eslint-disable-next-line standard/no-callback-literal
    callback({
      component: instance,
      destroy() {}
    });
  }
  ref(void 0);
};
const styles = _reactNative.StyleSheet.create({
  container: {
    position: 'absolute',
    flex: 1,
    left: 0,
    top: 0,
    bottom: 0,
    width: '100%',
    flexDirection: 'column',
    alignItems: 'center',
    zIndex: 9999
  },
  containerCentertrue: {
    justifyContent: 'center'
  },
  containerCenterfalse: {
    justifyContent: 'flex-end'
  },
  innerContainer: {
    minWidth: (0, _pt.default)(288),
    maxWidth: (0, _pt.default)(480),
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center',
    paddingTop: (0, _pt.default)(48),
    paddingBottom: (0, _pt.default)(48),
    paddingLeft: (0, _pt.default)(60),
    paddingRight: (0, _pt.default)(60),
    borderRadius: (0, _pt.default)(24)
  },
  iconContainer: {
    width: '100%',
    justifyContent: 'center',
    alignItems: 'center',
    marginBottom: (0, _pt.default)(16)
  },
  title: {
    fontSize: (0, _pt.default)(32),
    marginBottom: (0, _pt.default)(2),
    color: '#fff'
  },
  textAligntrue: {
    textAlign: 'center'
  },
  textAlignfalse: {
    textAlign: 'left'
  },
  textSizelarge: {
    fontSize: (0, _pt.default)(32)
  },
  textSizesmall: {
    fontSize: (0, _pt.default)(24)
  }
});
//# sourceMappingURL=notification.js.map