import React, { useCallback } from 'react';
import { View, Text, TouchableHighlight } from 'react-native';
import Icon from '../icon';
import CheckboxGroup from '../checkboxgroup';
import toObj from '../utils/style-to-obj';
import fConStyle from '../utils/filter-container-style';
import fTextStyle from '../utils/filter-text-style';
import { useConfig } from '../configprovider';
import checkboxStyles from './styles';
const defaultProps = {
  checked: false,
  disabled: false,
  textPosition: 'right',
  iconSize: 18,
  iconName: 'check-normal',
  iconActiveName: 'checked',
  iconIndeterminateName: 'check-disabled',
  onChange: (state, label) => {},
  style: {}
};
export const Checkbox = props => {
  const {
    children
  } = {
    ...defaultProps,
    ...props
  };
  const {
    iconName,
    iconSize,
    label,
    textPosition,
    iconActiveName,
    checked,
    disabled,
    onChange,
    indeterminate,
    iconIndeterminateName,
    getParentVals,
    max,
    style
  } = props;
  const {
    theme
  } = useConfig();
  const styles = checkboxStyles(theme);
  const onPressCallback = useCallback(() => {
    if (!disabled) {
      const latest = !checked;
      if (max !== undefined && latest && getParentVals().length >= max) return;
      onChange && onChange(latest, label || children);
    }
  }, [disabled, checked, max, getParentVals, onChange]);
  const wrapStyle = [styles.container, fConStyle(toObj(style))];
  const textStyle = [styles.text, styles[`textPosition${textPosition}`], fTextStyle(toObj(style)), styles[`textDisabled${disabled}`]];
  const iconStyle = [styles[`icon${textPosition}`]];
  const renderText = () => {
    if (typeof children === 'string') {
      return /*#__PURE__*/React.createElement(Text, {
        style: textStyle
      }, children);
    }
    if (label) {
      return /*#__PURE__*/React.createElement(Text, {
        style: textStyle
      }, label);
    }
  };
  const renderIcon = () => {
    if (disabled) {
      // 如果是禁止的状态
      if (indeterminate) {
        return /*#__PURE__*/React.createElement(Icon, {
          name: checked ? iconIndeterminateName : iconName,
          color: checked ? '#b1b1b1' : '#d6d6d6',
          size: iconSize,
          style: iconStyle
        });
      }
      return /*#__PURE__*/React.createElement(Icon, {
        name: checked ? iconActiveName : iconName,
        color: checked ? '#b1b1b1' : '#d6d6d6',
        size: iconSize,
        style: iconStyle
      });
    } else {
      if (indeterminate) {
        return /*#__PURE__*/React.createElement(Icon, {
          name: checked ? iconIndeterminateName : iconName,
          color: checked ? '#fa2c19' : '#d6d6d6',
          size: iconSize,
          style: iconStyle
        });
      }
      return /*#__PURE__*/React.createElement(Icon, {
        name: checked ? iconActiveName : iconName,
        color: checked ? '#f50f16' : '#d6d6d6',
        size: iconSize,
        style: iconStyle
      });
    }
  };
  const renderChildren = () => {
    if (textPosition === 'left') {
      return /*#__PURE__*/React.createElement(React.Fragment, null, renderText(), renderIcon());
    } else {
      return /*#__PURE__*/React.createElement(React.Fragment, null, renderIcon(), renderText());
    }
  };
  if (disabled) {
    return /*#__PURE__*/React.createElement(View, {
      style: wrapStyle
    }, renderChildren());
  }
  return /*#__PURE__*/React.createElement(TouchableHighlight, {
    underlayColor: null,
    activeOpacity: 1,
    onPress: onPressCallback
  }, /*#__PURE__*/React.createElement(View, {
    style: wrapStyle
  }, renderChildren()));
};
Checkbox.defaultProps = defaultProps;
Checkbox.displayName = 'NutCheckBox';
Checkbox.Group = CheckboxGroup;
//# sourceMappingURL=checkbox.js.map