import React from 'react';
import { View } from 'react-native';
import { useConfig } from '../configprovider';
import gridStyles from './styles';
const defaultProps = {
  columnNum: 4,
  border: true,
  gutter: 0,
  center: true,
  square: false,
  reverse: false,
  direction: 'vertical',
  iconSize: 28,
  iconColor: ''
};
export const Grid = props => {
  const {
    children,
    columnNum,
    border,
    gutter,
    center,
    square,
    reverse,
    direction,
    style,
    iconSize,
    iconColor,
    className,
    ...rest
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const mStyles = gridStyles(theme);
  const childrenDom = React.Children.toArray(children);
  const pxCheck = value => {
    let getValue = value;
    if (Number.isNaN(Number(value)) || typeof value === 'string') {
      getValue = parseInt(String(value));
    }
    if (!getValue || getValue == '') {
      getValue = 0;
    }
    return getValue;
  };
  const rootStyle = () => {
    let styleSelf = {};
    if (style) {
      styleSelf = style;
    }
    if (gutter) {
      styleSelf.paddingLeft = pxCheck(gutter);
    }
    return styleSelf;
  };
  return /*#__PURE__*/React.createElement(View, {
    style: [mStyles.nut_grid_container, rootStyle()]
  }, childrenDom.map((item, idex) => {
    return /*#__PURE__*/React.cloneElement(item, {
      index: idex,
      columnNum,
      center,
      border,
      gutter,
      square,
      reverse,
      direction,
      parentIconSize: iconSize,
      parentIconColor: iconColor
    });
  }));
};
Grid.defaultProps = defaultProps;
Grid.displayName = 'NutGrid';
//# sourceMappingURL=grid.js.map