function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState, useEffect } from 'react';
import { View, TextInput, TouchableOpacity, Platform } from 'react-native';
import Icon from '../icon/index';
import { ComponentDefaults } from '../utils/typings';
import pt from '../utils/pt';
import { useConfig } from '../configprovider';
import inputNumberStyles from './styles';
const defaultProps = {
  ...ComponentDefaults,
  disabled: false,
  buttonSize: '',
  min: 1,
  max: 9999,
  inputWidth: '',
  readonly: false,
  modelValue: 0,
  step: 1,
  decimalPlaces: 0,
  isAsync: false
};
function pxCheck(value) {
  return value ? pt(parseInt(`${value}`)) : 0;
}
export const InputNumber = props => {
  const {
    children,
    disabled,
    buttonSize,
    min,
    max,
    inputWidth,
    readonly,
    modelValue,
    decimalPlaces,
    step,
    isAsync,
    className,
    style,
    onAdd,
    onReduce,
    onOverlimit,
    onBlurFuc,
    onFocus,
    onChangeFuc,
    iconClassPrefix,
    iconFontClassName,
    ...restProps
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const mStyles = inputNumberStyles(theme);
  const [inputValue, setInputValue] = useState(modelValue);
  useEffect(() => {
    const outputValue = fixedDecimalPlaces(modelValue);
    setInputValue(outputValue);
  }, [modelValue]);
  const styles = {
    ...style
  };
  const addAllow = function () {
    let value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Number(inputValue);
    return value < Number(max) && !disabled;
  };
  const reduceAllow = function () {
    let value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Number(inputValue);
    return value > Number(min) && !disabled;
  };
  const fixedDecimalPlaces = v => {
    return Number(v).toFixed(Number(decimalPlaces));
  };
  const emitChange = (value, e) => {
    const outputValue = fixedDecimalPlaces(value);
    onChangeFuc && onChangeFuc(outputValue, e);
    if (!isAsync) {
      if (Number(outputValue) < Number(min)) {
        setInputValue(Number(min));
      } else if (Number(outputValue) > Number(max)) {
        setInputValue(Number(max));
      } else {
        setInputValue(outputValue);
      }
    }
  };
  const reduceNumber = e => {
    onReduce && onReduce(e);
    if (reduceAllow()) {
      const outputValue = Number(inputValue) - Number(step);
      emitChange(outputValue, e);
    } else {
      onOverlimit && onOverlimit(e);
    }
  };
  const addNumber = e => {
    onAdd && onAdd(e);
    if (addAllow()) {
      const outputValue = Number(inputValue) + Number(step);
      emitChange(outputValue, e);
    } else {
      onOverlimit && onOverlimit(e);
    }
  };
  const changeValue = e => {
    const value = Number(e === null || e === void 0 ? void 0 : e.nativeEvent.text);
    onChangeFuc && onChangeFuc(value, e);
    if (!isAsync) {
      if (Number.isNaN(value)) {
        setInputValue(inputValue);
      } else {
        setInputValue(value);
      }
    }
  };
  const focusValue = e => {
    if (disabled) return;
    if (readonly) return;
    onFocus && onFocus(e);
  };
  const burValue = e => {
    if (disabled) return;
    if (readonly) return;
    let value = Number(e === null || e === void 0 ? void 0 : e.nativeEvent.text);
    if (value < Number(min)) {
      value = Number(min);
    } else if (value > Number(max)) {
      value = Number(max);
    }
    emitChange(value, e);
    onBlurFuc && onBlurFuc(e);
  };
  return /*#__PURE__*/React.createElement(View, _extends({
    style: [styles, {
      flexDirection: 'row',
      alignItems: 'center',
      paddingVertical: pt(10)
    }]
  }, restProps), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: reduceNumber
  }, /*#__PURE__*/React.createElement(Icon, {
    style: mStyles.nut_icon_marginH,
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    size: buttonSize,
    color: reduceAllow() ? "#2c2c2c" : "#bfbfbf",
    name: 'minus'
  })), Platform.OS === 'web' ? /*#__PURE__*/React.createElement(View, {
    style: pxCheck(inputWidth) == 0 ? mStyles.nut_inputnumber_zerowidth : {
      width: pxCheck(inputWidth),
      ...mStyles.nut_inputnumber_fixwidth
    }
  }, /*#__PURE__*/React.createElement("input", {
    type: "number",
    min: min,
    max: max,
    style: {
      width: pxCheck(inputWidth) == 0 ? 50 : pxCheck(inputWidth),
      textAlign: 'center',
      borderWidth: 0,
      backgroundColor: 'transparent'
    },
    disabled: disabled,
    readOnly: readonly,
    value: inputValue,
    onInput: changeValue,
    onBlur: burValue,
    onFocus: focusValue
  })) : /*#__PURE__*/React.createElement(View, {
    style: pxCheck(inputWidth) == 0 ? mStyles.nut_inputnumber_zerowidth : {
      width: pxCheck(inputWidth),
      ...mStyles.nut_inputnumber_fixwidth
    }
  }, /*#__PURE__*/React.createElement(TextInput, {
    type: "number",
    min: min,
    max: max,
    style: {
      color: disabled ? '#d5d5d5' : '#000000',
      padding: 0
    },
    textAlign: "center",
    editable: !(readonly || disabled),
    value: `${inputValue}`,
    onChange: changeValue,
    onBlur: burValue,
    onFocus: focusValue
  })), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: addNumber
  }, /*#__PURE__*/React.createElement(Icon, {
    style: mStyles.nut_icon_marginH,
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    size: buttonSize,
    color: addAllow() ? "#2c2c2c" : "#bfbfbf",
    name: 'plus',
    onPress: addNumber
  })));
};
InputNumber.defaultProps = defaultProps;
InputNumber.displayName = 'NutInputNumber';
//# sourceMappingURL=inputnumber.js.map