import React from 'react';
import Icon from '../icon/index';
import { TouchableOpacity, View, Text, StyleSheet } from 'react-native';
import { ComponentDefaults } from '../utils/typings';
import statusBarHeight from '../utils/statusBarHeight';
import pt from '../utils/pt';
const defaultProps = {
  ...ComponentDefaults,
  title: '',
  desc: '',
  leftShow: true,
  titIcon: '',
  className: '',
  leftText: '',
  fixed: false,
  safeAreaInsetTop: false,
  border: false,
  placeholder: false,
  zIndex: 10,
  style: {},
  onClickTitle: () => {},
  onClickIcon: () => {},
  onClickBack: () => {},
  onClickRight: () => {}
};
export const NavBar = props => {
  const {
    desc,
    title,
    titIcon,
    leftShow,
    className,
    style,
    leftText,
    fixed,
    safeAreaInsetTop,
    border,
    placeholder,
    zIndex,
    onClickTitle,
    onClickIcon,
    onClickBack,
    onClickRight,
    iconClassPrefix,
    iconFontClassName
  } = {
    ...defaultProps,
    ...props
  };
  const children = Array.isArray(props.children) ? props.children : [props.children];
  const slot = children.reduce((slot, item) => {
    const data = slot;
    if (item && item.props) {
      data[item.props.slot] = item;
    }
    return data;
  }, {});
  const customStyles = () => {
    return {
      ...style,
      zIndex
    };
  };
  const renderLeft = () => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: mStyles.mLeft,
      onPress: e => onClickBack(e)
    }, leftShow && /*#__PURE__*/React.createElement(Icon, {
      classPrefix: iconClassPrefix,
      fontClassName: iconFontClassName,
      name: "left",
      color: "#979797",
      size: pt(32)
    }), leftText ? /*#__PURE__*/React.createElement(View, {
      style: mStyles.marL10
    }, /*#__PURE__*/React.createElement(Text, null, leftText)) : null, slot.left);
  };
  const renderContent = () => {
    return /*#__PURE__*/React.createElement(View, {
      style: mStyles.content
    }, title ? /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: e => onClickTitle(e)
    }, /*#__PURE__*/React.createElement(Text, null, " ", title)) : null, titIcon ? /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: e => onClickIcon(e),
      style: mStyles.marL10
    }, /*#__PURE__*/React.createElement(Icon, {
      classPrefix: iconClassPrefix,
      fontClassName: iconFontClassName,
      name: titIcon
    })) : null, slot.content);
  };
  const renderRight = () => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: mStyles.mRright,
      onPress: e => onClickRight(e)
    }, desc ? /*#__PURE__*/React.createElement(View, {
      style: {
        marginRight: 10
      }
    }, /*#__PURE__*/React.createElement(Text, null, desc)) : null, slot.right);
  };
  const renderWrapper = () => {
    return /*#__PURE__*/React.createElement(View, {
      style: [mStyles.wrapper, {
        width: '100%',
        borderBottomWidth: border ? 1 : 0,
        zIndex
      }, style]
    }, renderLeft(), renderContent(), renderRight());
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, safeAreaInsetTop ? /*#__PURE__*/React.createElement(View, {
    style: {
      paddingTop: statusBarHeight
    }
  }, renderWrapper()) : renderWrapper());
};
const mStyles = StyleSheet.create({
  wrapper: {
    height: pt(100),
    backgroundColor: '#fff',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    borderBottomColor: '#f2f2f2'
  },
  content: {
    justifyContent: 'center',
    alignItems: 'center',
    flexDirection: 'row',
    height: '100%'
  },
  mRright: {
    height: '100%',
    justifyContent: 'center',
    alignItems: 'center',
    flexDirection: 'row',
    position: 'absolute',
    right: 0,
    top: 0
  },
  mLeft: {
    height: '100%',
    justifyContent: 'center',
    alignItems: 'center',
    flexDirection: 'row',
    position: 'absolute',
    left: 10,
    top: 0
  },
  marL10: {
    marginLeft: pt(10)
  }
});
NavBar.defaultProps = defaultProps;
NavBar.displayName = 'NutNavBar';
//# sourceMappingURL=navbar.js.map