import React, { useState, useRef } from 'react';
import toObj from '../utils/style-to-obj';
import fConStyle from '../utils/filter-container-style';
import fTexStyle from '../utils/filter-text-style';
import Carousel from './carousel';
import { Text, View, TouchableHighlight } from 'react-native';
import { useConfig } from '../configprovider';
import noticebarStyles from './styles';
import Icon from '../icon';
import Marquee from './marquee';
const defaultProps = {
  // 滚动方向  across 横向 vertical 纵向
  direction: 'across',
  list: [],
  // 纵向滚动数据列表
  standTime: 1000,
  complexAm: false,
  height: 40,
  text: '',
  closeMode: false,
  wrapable: false,
  leftIcon: '',
  color: '',
  backgroundColor: '',
  delay: 1,
  scrollable: true,
  speed: 50
};
export const NoticeBar = props => {
  const {
    children,
    style,
    direction,
    list,
    standTime,
    complexAm,
    height,
    text,
    closeMode,
    wrapable,
    leftIcon,
    color,
    backgroundColor,
    delay,
    scrollable,
    speed,
    rightIcon,
    onClose,
    onClick
  } = {
    ...defaultProps,
    ...props
  };
  const [showNoticeBar, SetShowNoticeBar] = useState(true);
  const [noticeBarWidth, setNoticeBarWidth] = useState(0);
  const scrollList = useRef([]);
  const {
    theme
  } = useConfig();
  const styles = noticebarStyles(theme);
  const handleClick = event => {
    onClick && onClick(event);
  };
  const onIconClick = event => {
    SetShowNoticeBar(!closeMode);
    onClose && onClose(event);
    onClick && onClick(event);
  };

  /**
   * 点击滚动单元
   */
  const go = item => {
    onClick && onClick(item);
  };
  const iconShow = () => {
    if (leftIcon === 'close') {
      return false;
    }
    return true;
  };
  const getMaxWidth = () => {
    if (typeof children === 'string') {
      return (children.length + 160) * 6;
    }
    if (children) {
      return children;
    }
    return (text.length + 160) * 6;
  };
  const textStyle = [styles.marquee, fTexStyle(toObj(style || {})), color ? {
    color
  } : {}];
  const renderText = () => {
    if (wrapable) {
      return /*#__PURE__*/React.createElement(Text, {
        style: textStyle
      }, children || text);
    }
    return /*#__PURE__*/React.createElement(Text, {
      numberOfLines: 1,
      ellipsizeMode: "tail",
      style: textStyle
    }, children || text);
  };
  if (!showNoticeBar) {
    return /*#__PURE__*/React.createElement(View, null);
  }
  const acrossStyle = [styles.acrossContainer, fConStyle(toObj(style || {})), backgroundColor ? {
    backgroundColor
  } : {}];
  const renderAcross = () => {
    return /*#__PURE__*/React.createElement(View, {
      style: acrossStyle
    }, iconShow() ? /*#__PURE__*/React.createElement(View, {
      style: styles.iconContainer
    }, /*#__PURE__*/React.createElement(Icon, {
      name: leftIcon || 'notice',
      color: theme['$noticebar-color'] || '#d9500b',
      size: theme['$noticebar-left-icon-width'] || 16
    })) : null, /*#__PURE__*/React.createElement(View, {
      style: styles.contentC
    }, scrollable ? /*#__PURE__*/React.createElement(Marquee, {
      style: styles.marquee,
      text: children || text,
      speed: speed,
      delay: delay,
      wrapable: wrapable,
      maxWidth: wrapable ? 350 : getMaxWidth()
    }) : renderText()), closeMode || rightIcon ? /*#__PURE__*/React.createElement(TouchableHighlight, {
      underlayColor: null,
      activeOpacity: 1,
      onPress: onIconClick
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.rIconContainer
    }, /*#__PURE__*/React.createElement(Icon, {
      name: rightIcon || 'close',
      size: theme['$noticebar-right-icon-width'] || 16,
      color: color || theme['$noticebar-color'] || '#d9500b'
    }))) : null);
  };
  const cloneChild = (listItem, listIndex) => {
    return React.Children.map(children, function (child, index) {
      if (child && index === listIndex) {
        return /*#__PURE__*/React.cloneElement(child, {
          key: listIndex,
          children: listItem
        });
      }
      return null;
    });
  };
  const getChilden = () => {
    const arr = [];
    React.Children.map(children, child => {
      arr.push(child.props.children);
    });
    return arr;
  };
  const renderVertical = () => {
    return /*#__PURE__*/React.createElement(View, {
      style: acrossStyle,
      onLayout: e => {
        let width = e.nativeEvent && e.nativeEvent.layout && e.nativeEvent.layout.width;
        setNoticeBarWidth(width || 0);
      }
    }, children ? /*#__PURE__*/React.createElement(Carousel, {
      style: [styles.horseLampList, {
        width: noticeBarWidth - 60,
        height
      }],
      selectedIndex: 1,
      autoplay: true,
      infinite: true,
      autoplayInterval: standTime,
      vertical: true
    }, getChilden().map((item, index) => {
      return cloneChild(item, index);
    })) : /*#__PURE__*/React.createElement(Carousel, {
      style: [styles.horseLampList, {
        width: noticeBarWidth - 60,
        height
      }],
      selectedIndex: 1,
      autoplay: true,
      infinite: true,
      autoplayInterval: standTime,
      vertical: true
    }, list.map((item, index) => {
      return /*#__PURE__*/React.createElement(TouchableHighlight, {
        key: index,
        style: {
          height,
          justifyContent: 'center'
        },
        underlayColor: null,
        activeOpacity: 1,
        onPress: () => {
          go(item);
        }
      }, /*#__PURE__*/React.createElement(Text, {
        style: textStyle
      }, item));
    })), rightIcon || (closeMode ? /*#__PURE__*/React.createElement(TouchableHighlight, {
      underlayColor: null,
      activeOpacity: 1,
      style: styles.rIconContainer,
      onPress: onIconClick
    }, /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(Icon, {
      name: "close",
      size: 11,
      color: color || '#d9500b'
    }))) : null));
  };
  return /*#__PURE__*/React.createElement(View, null, direction === 'across' ? renderAcross() : null, (list.length || children) && direction === 'vertical' ? renderVertical() : null);
};
NoticeBar.defaultProps = defaultProps;
NoticeBar.displayName = 'NutNoticeBar';
//# sourceMappingURL=noticebar.js.map