import React, { useEffect, useRef, useState } from 'react';
import { Animated, Easing, TouchableOpacity, Modal } from 'react-native';
import { useConfig } from '../configprovider';
import overlayStyles from './styles';
export const defaultOverlayProps = {
  zIndex: 2000,
  duration: 0.3,
  overlayClass: '',
  closeOnClickOverlay: true,
  visible: false,
  overlayStyle: {},
  onPress: () => {}
};
export const Overlay = props => {
  const {
    children,
    zIndex,
    duration,
    overlayClass,
    closeOnClickOverlay,
    visible,
    overlayStyle,
    onPress,
    ...rest
  } = {
    ...defaultOverlayProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const mStyles = overlayStyles(theme);
  const [show, setShow] = useState(visible);
  useEffect(() => {
    visible && setShow(visible);
  }, [visible]);
  const styles = {
    zIndex,
    ...overlayStyle
  };
  const handleClick = e => {
    if (closeOnClickOverlay) {
      props.onPress && props.onPress(e);
      const id = setTimeout(() => {
        setShow(!show);
      }, duration * 1000 * 0.8);
    }
  };
  const animatedValue = useRef(new Animated.Value(0)).current;
  Animated.timing(animatedValue, {
    toValue: visible ? 1 : 0,
    duration: duration * 1000,
    easing: Easing.ease,
    useNativeDriver: true
  }).start();
  return /*#__PURE__*/React.createElement(Modal, {
    animationType: "none",
    transparent: true,
    visible: show
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [mStyles.nut_overlay_full, {
      opacity: animatedValue,
      ...styles
    }]
  }, /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: handleClick,
    activeOpacity: 1,
    style: [mStyles.nut_overlay_full_bg, {
      ...styles
    }]
  }, children)));
};
Overlay.defaultProps = defaultOverlayProps;
Overlay.displayName = 'NutOverlay';
//# sourceMappingURL=overlay.js.map