import React from 'react';
import { View, Text } from 'react-native';
import toObj from '../utils/style-to-obj';
import fConStyle from '../utils/filter-container-style';
import fTextStyle from '../utils/filter-text-style';
import pt from '../utils/pt';
import { useConfig } from '../configprovider';
import priceStyles from './styles';

// 按钮大小

const defaultProps = {
  price: 0,
  needSymbol: true,
  symbol: '&yen;',
  decimalDigits: 2,
  thousands: false,
  position: 'before',
  size: 'large'
};
export const Price = props => {
  const {
    price,
    needSymbol,
    symbol,
    decimalDigits,
    thousands,
    style,
    position,
    size
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const styles = priceStyles(theme);
  const replaceSpecialChar = symbol => {
    let desSymbol = symbol;
    desSymbol = symbol.replace(/&quot;/g, '"');
    desSymbol = symbol.replace(/&amp;/g, '&');
    desSymbol = symbol.replace(/&lt;/g, '<');
    desSymbol = symbol.replace(/&gt;/g, '>');
    desSymbol = symbol.replace(/&nbsp;/g, ' ');
    desSymbol = symbol.replace(/&yen;/g, '￥');
    return desSymbol;
  };
  const checkPoint = price => {
    return String(price).indexOf('.') > 0;
  };
  const formatThousands = num => {
    if (Number(num) === 0) {
      num = 0;
    }
    if (checkPoint(num)) {
      num = Number(num).toFixed(decimalDigits);
      num = typeof num.split('.') === 'string' ? num.split('.') : num.split('.')[0];
    } else {
      num = num.toString();
    }
    if (thousands) {
      return (num || 0).toString().replace(/(\d)(?=(?:\d{3})+$)/g, '$1,');
    }
    return num;
  };
  const formatDecimal = decimalNum => {
    if (Number(decimalNum) === 0) {
      decimalNum = 0;
    }
    if (checkPoint(decimalNum)) {
      decimalNum = Number(decimalNum).toFixed(decimalDigits);
      decimalNum = typeof decimalNum.split('.') === 'string' ? 0 : decimalNum.split('.')[1];
    } else {
      decimalNum = 0;
    }
    const result = `0.${decimalNum}`;
    const resultFixed = Number(result).toFixed(decimalDigits);
    return String(resultFixed).substring(2, resultFixed.length);
  };
  const wrapStyle = [styles.container, fConStyle(toObj(style || {}))];
  const symbolStyle = [styles.defaultText, fTextStyle(toObj(style || {})), {
    marginTop: pt(2)
  }, styles[`symbol${size}`]];
  const bigStyle = [styles.defaultText, size === 'large' ? {
    marginTop: -pt(6)
  } : {}, fTextStyle(toObj(style || {})), styles[`big${size}`]];
  const pointStyle = [styles.defaultText, size === 'large' ? {
    marginTop: -pt(4)
  } : {}, size === 'small' ? {
    marginTop: -pt(6)
  } : {}, fTextStyle(toObj(style || {})), styles[`point${size}`]];
  const smallStyle = [styles.defaultText, fTextStyle(toObj(style || {})), styles[`small${size}`]];
  return /*#__PURE__*/React.createElement(View, {
    style: wrapStyle
  }, position === 'before' && needSymbol ? /*#__PURE__*/React.createElement(Text, {
    style: symbolStyle
  }, replaceSpecialChar(symbol)) : null, /*#__PURE__*/React.createElement(Text, {
    style: bigStyle
  }, formatThousands(price)), decimalDigits ? /*#__PURE__*/React.createElement(Text, {
    style: pointStyle
  }, ".") : null, decimalDigits ? /*#__PURE__*/React.createElement(Text, {
    style: smallStyle
  }, formatDecimal(price)) : null, position === 'after' && needSymbol ? /*#__PURE__*/React.createElement(Text, {
    style: symbolStyle
  }, replaceSpecialChar(symbol)) : null);
};
Price.defaultProps = defaultProps;
Price.displayName = 'NutPrice';
//# sourceMappingURL=price.js.map