function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState, useEffect, useRef } from 'react';
import { View, Text, Animated, Platform } from 'react-native';
import Icon from '../icon';
import { ComponentDefaults } from '../utils/typings';
import pt from '../utils/pt';
import * as LinearGradient from 'react-native-linear-gradient';
import { useConfig } from '../configprovider';
import progressStyles from './styles';
const defaultProps = {
  ...ComponentDefaults,
  className: '',
  style: {},
  isShowPercentage: true,
  percentage: 0,
  fillColor: '#f3f3f3',
  strokeColor: ['#fa2c19', '#fa6419'],
  strokeWidth: '10',
  textColor: '',
  textWidth: '',
  showText: true,
  textInside: false,
  textBackground: ['#fa2c19', '#fa6419'],
  textType: 'text',
  status: false,
  iconName: 'checked',
  iconColor: '#439422',
  iconSize: '16px',
  children: undefined
};
export const Progress = props => {
  const [proWidth, setProWidth] = useState(0);
  const [proHeight, setProHeight] = useState(0);
  const [proInnerWidth, setProInnerWidth] = useState(0);
  const [proInnerHeight, setProInnerHeight] = useState(0);
  const animationRef = useRef(new Animated.Value(0));
  const animationRefTag = useRef(new Animated.Value(0));
  const {
    className,
    style,
    isShowPercentage,
    percentage,
    fillColor,
    strokeColor,
    strokeWidth,
    size,
    textColor,
    textWidth,
    showText,
    textInside,
    textBackground,
    textType,
    status,
    iconName,
    iconColor,
    iconSize,
    children,
    iconClassPrefix,
    iconFontClassName,
    ...rest
  } = {
    ...defaultProps,
    ...props
  };
  const {
    theme
  } = useConfig();
  const styles = progressStyles(theme);
  useEffect(() => {
    //setValue(props.value)
    startAnimated();
  }, [props.percentage, proWidth]);
  const startAnimated = () => {
    Animated.timing(animationRef.current, {
      toValue: parseInt(props.percentage / 100 * proWidth),
      duration: 800,
      useNativeDriver: false
    }).start();

    //let leftV = 0;
    Animated.timing(animationRefTag.current, {
      toValue: parseInt(props.percentage / 100 * proWidth) - proInnerWidth / 2,
      duration: 800,
      useNativeDriver: false
    }).start();
  };
  const getHeight = () => {
    let height;
    switch (size) {
      case 'small':
        height = pt(12);
        break;
      case 'base':
        height = pt(20);
        break;
      case 'large':
        height = pt(30);
        break;
      default:
        height = parseInt(strokeWidth);
        break;
    }
    return height;
  };

  //hex -> rgba
  const hexToRgba = (hex, opacity) => {
    return 'rgba(' + parseInt('0x' + hex.slice(1, 3)) + ',' + parseInt('0x' + hex.slice(3, 5)) + ',' + parseInt('0x' + hex.slice(5, 7)) + ',' + opacity + ')';
  };
  const LinearGradientModuleRef = LinearGradient;
  const LinearGradientComponent = LinearGradientModuleRef.LinearGradient || LinearGradientModuleRef.default;
  return /*#__PURE__*/React.createElement(View, _extends({
    style: [styles.containerOut, style]
  }, rest), /*#__PURE__*/React.createElement(View, {
    style: styles.containerInner
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.progressBg, {
      backgroundColor: fillColor || '#f3f3f3',
      height: getHeight(),
      borderRadius: getHeight() / 2
    }],
    onLayout: e => {
      setProWidth(e.nativeEvent.layout.width);
      setProHeight(e.nativeEvent.layout.height);
    }
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: {
      width: animationRef.current,
      height: getHeight()
    }
  }, Platform.OS === 'web' ? /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1,
      height: getHeight(),
      borderRadius: getHeight() / 2,
      background: `linear-gradient(90deg, ${hexToRgba(strokeColor[0], 1)} 0%,${hexToRgba(strokeColor[1], 1)} 100%)`
    }
  }) : /*#__PURE__*/React.createElement(LinearGradientComponent, {
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    },
    colors: strokeColor,
    style: {
      flex: 1,
      height: getHeight(),
      borderRadius: getHeight() / 2
    }
  })), showText && textInside && /*#__PURE__*/React.createElement(Animated.View, {
    style: {
      position: 'absolute',
      marginLeft: animationRef.current,
      left: -proInnerWidth / 2,
      top: -((proInnerHeight - proHeight) / 2),
      marginBottom: 'auto',
      marginTop: 'auto'
    },
    onLayout: e => {
      setProInnerWidth(e.nativeEvent.layout.width);
      setProInnerHeight(e.nativeEvent.layout.height);
    }
  }, textType === 'icon' ? /*#__PURE__*/React.createElement(Icon, {
    classPrefix: iconClassPrefix,
    fontClassName: iconFontClassName,
    size: iconSize,
    name: iconName,
    color: iconColor
  }) : /*#__PURE__*/React.createElement(LinearGradientComponent, {
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    },
    colors: textBackground,
    style: styles.progreessTg
  }, textType === 'text' && /*#__PURE__*/React.createElement(Text, {
    style: {
      color: textColor || '#333'
    }
  }, percentage, isShowPercentage ? '%' : '')), Platform.OS === 'web' ? /*#__PURE__*/React.createElement(View, {
    style: [styles.progreessTg, {
      background: `linear-gradient(90deg, ${hexToRgba(textBackground[0], 1)} 0%,${hexToRgba(textBackground[1], 1)} 100%)`
    }]
  }, textType === 'text' && /*#__PURE__*/React.createElement(Text, {
    style: {
      color: textColor || '#333'
    }
  }, percentage, isShowPercentage ? '%' : '')) : /*#__PURE__*/React.createElement(LinearGradientComponent, {
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    },
    colors: textBackground,
    style: styles.progreessTg
  }, textType === 'text' && /*#__PURE__*/React.createElement(Text, {
    style: {
      color: textColor || '#333'
    }
  }, percentage, isShowPercentage ? '%' : '')))), showText && !textInside && /*#__PURE__*/React.createElement(React.Fragment, null, children ? /*#__PURE__*/React.createElement(View, null, children) : /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(Text, {
    style: {
      color: textColor || '#000'
    }
  }, percentage, isShowPercentage ? '%' : '')))));
};
Progress.defaultProps = defaultProps;
Progress.displayName = 'NutProgress';
//# sourceMappingURL=progress.js.map