import React, { useEffect, useRef, useState } from 'react';
import { View, Text, TextInput, TouchableOpacity } from 'react-native';
import Icon from '../icon';
import { ComponentDefaults } from '../utils/typings';
import { useConfig } from '../configprovider';
import searchbarStyles from './styles';
const defaultProps = {
  ...ComponentDefaults,
  placeholder: '',
  shape: 'square',
  disabled: false,
  maxLength: 9999,
  clearable: true,
  align: 'left',
  readonly: true,
  autoFocus: false,
  label: '',
  leftinIcon: /*#__PURE__*/React.createElement(Icon, {
    name: "search",
    size: "12"
  })
};
export const SearchBar = props => {
  const {
    theme
  } = useConfig();
  const mStyles = searchbarStyles(theme);
  const searchRef = useRef(null);
  const [value, setValue] = useState(() => props.value);
  const {
    placeholder,
    shape,
    disabled,
    maxLength,
    clearable,
    align,
    readOnly,
    autoFocus,
    label,
    actionText,
    leftinIcon,
    rightinIcon,
    leftoutIcon,
    rightoutIcon,
    onChange,
    onFocus,
    onBlur,
    onClear,
    onCancel,
    onSearch,
    onClickLeftinIcon,
    onClickLeftoutIcon,
    onClickRightinIcon,
    onClickRightoutIcon,
    iconClassPrefix,
    iconFontClassName
  } = {
    ...defaultProps,
    ...props
  };
  const alignClass = `${align}`;
  const change = event => {
    const {
      text
    } = event === null || event === void 0 ? void 0 : event.nativeEvent;
    onChange && (onChange === null || onChange === void 0 ? void 0 : onChange(text, event));
    setValue(text);
  };
  const focus = event => {
    const {
      text
    } = event === null || event === void 0 ? void 0 : event.nativeEvent;
    onFocus && (onFocus === null || onFocus === void 0 ? void 0 : onFocus(text, event));
  };
  const blur = event => {
    const searchSelf = searchRef.current;
    searchSelf && searchSelf.blur();
    const {
      text
    } = event === null || event === void 0 ? void 0 : event.nativeEvent;
    onBlur && (onBlur === null || onBlur === void 0 ? void 0 : onBlur(text, event));
  };
  useEffect(() => {
    setValue(props.value);
  }, [props.value]);
  useEffect(() => {
    if (autoFocus) {
      const searchSelf = searchRef.current;
      searchSelf && searchSelf.focus();
    }
  }, [autoFocus]);
  const renderField = () => {
    return /*#__PURE__*/React.createElement(TextInput, {
      ref: searchRef,
      style: {
        ...props.style,
        paddingRight: 10,
        padding: 0
      },
      value: value || '',
      placeholder: placeholder || '请输入内容',
      disabled: disabled,
      readOnly: readOnly,
      maxLength: maxLength,
      onKeyPress: onKeypress,
      onChange: e => change(e),
      onFocus: e => focus(e),
      onBlur: e => blur(e)
    });
  };
  const renderLeftinIcon = () => {
    if (!leftinIcon) return null;
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: mStyles.nut_search_left_in_marginH,
      onPress: e => clickLeftIcon('in-left', e)
    }, leftinIcon);
  };
  const renderLeftoutIcon = () => {
    if (!leftoutIcon) return null;
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: mStyles.nut_search_left_icon_marginright,
      onPress: e => clickLeftIcon('out-left', e)
    }, leftoutIcon);
  };
  const clickLeftIcon = (flag, event) => {
    if (flag === 'in-left') {
      onClickLeftinIcon && onClickLeftinIcon(value, event);
    } else {
      onClickLeftoutIcon && onClickLeftoutIcon(value, event);
    }
  };
  const renderRightinIcon = () => {
    if (!rightinIcon) return null;
    return /*#__PURE__*/React.createElement(View, {
      onClick: e => clickRightIcon('in-right', e),
      style: mStyles.nut_search_icon_marginH
    }, rightinIcon);
  };
  const renderRightoutIcon = () => {
    if (!rightoutIcon) return null;
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: e => clickRightIcon('out-right', e),
      style: mStyles.nut_search_out_marginleft
    }, rightoutIcon);
  };
  const clickRightIcon = (flag, event) => {
    if (flag === 'in-left') {
      onClickRightinIcon && onClickRightinIcon(value, event);
    } else {
      onClickRightoutIcon && onClickRightoutIcon(value, event);
    }
  };
  const handleClear = () => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: e => clearaVal(e),
      style: mStyles.nut_search_clear_marginright
    }, /*#__PURE__*/React.createElement(Icon, {
      classPrefix: iconClassPrefix,
      fontClassName: iconFontClassName,
      name: "circle-close",
      size: "12",
      color: "#555"
    }));
  };
  const clearaVal = event => {
    if (disabled || readOnly) {
      return;
    }
    setValue('');
    onClear && onClear(event);
  };
  const renderRightLabel = () => {
    if (actionText) {
      return /*#__PURE__*/React.createElement(TouchableOpacity, {
        style: mStyles.nut_label_marginleft,
        onPress: cancel
      }, /*#__PURE__*/React.createElement(Text, null, actionText));
    }
    return null;
  };
  const onKeypress = e => {
    if (e.key === 'Enter') {
      const event = e.nativeEvent;
      if (typeof event.cancelable !== 'boolean' || event.cancelable) {
        event.preventDefault();
      }
      onSearch && onSearch(value);
    }
  };
  const cancel = () => {
    onCancel && onCancel();
  };
  const renderLabel = () => {
    if (label) {
      return /*#__PURE__*/React.createElement(View, {
        style: mStyles.nut_label_margin
      }, /*#__PURE__*/React.createElement(Text, null, label));
    }
    return null;
  };
  return /*#__PURE__*/React.createElement(View, {
    style: [{
      ...mStyles.nut_searchbar_container,
      ...props.style
    }, {
      backgroundColor: props.background ? props.background : '#fff'
    }]
  }, renderLeftoutIcon(), renderLabel(), /*#__PURE__*/React.createElement(View, {
    style: [{
      ...mStyles.nut_searchbar_inner,
      borderRadius: shape === 'round' ? 20 : 0
    }, {
      backgroundColor: props.inputBackground ? props.inputBackground : '#f7f7f7'
    }]
  }, renderLeftinIcon(), /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1
    }
  }, renderField()), renderRightinIcon(), clearable && value ? handleClear() : null), renderRightoutIcon(), renderRightLabel());
};
SearchBar.defaultProps = defaultProps;
SearchBar.displayName = 'NutSearchBar';
//# sourceMappingURL=searchbar.js.map