import React, { useRef, useMemo } from 'react';
import { View } from 'react-native';
import { DataContext } from './userContext';
import fConStyle from '../utils/filter-container-style';
import toObj from '../utils/style-to-obj';
import PageView from './pageview';
import { useConfig } from '../configprovider';
import swiperStyles from './styles';
const defaultProps = {
  width: 375,
  height: 0,
  duration: 500,
  initPage: 0,
  autoPlay: 0,
  direction: 'horizontal',
  paginationColor: '#fff',
  paginationBgColor: '#d3d3d3',
  paginationVisible: false,
  loop: true,
  touchable: true,
  isCenter: false
};
export const Swiper = /*#__PURE__*/React.forwardRef((props, ref) => {
  const propSwiper = {
    ...defaultProps,
    ...props
  };
  const {
    width,
    height,
    children,
    direction,
    loop,
    pageContent,
    onChange,
    initPage,
    paginationColor,
    paginationBgColor,
    paginationVisible,
    touchable,
    autoPlay,
    isCenter,
    style
  } = propSwiper;
  const {
    theme
  } = useConfig();
  const styles = swiperStyles(theme);
  const pageViewRef = useRef(null);
  const isVertical = direction === 'vertical';
  const size = isVertical ? height : width;
  const {
    childs,
    childCount
  } = useMemo(() => {
    let childCount = 0;
    const childs = React.Children.map(children, child => {
      if (! /*#__PURE__*/React.isValidElement(child)) return null;
      childCount++;
      return child;
    });
    return {
      childs,
      childCount
    };
  }, [children]);
  // 父组件参数传入子组件item
  const parent = {
    propSwiper,
    size
  };
  const itemStyle2 = () => {
    const styleObj = {};
    if (size) {
      if (direction === 'horizontal') {
        styleObj.width = size;
      } else {
        styleObj.height = size;
      }
    }
    return styleObj;
  };
  const to = index => {
    const target = pageViewRef.current;
    target.goTo(index);
  };

  // 下一页
  const next = () => {
    const target = pageViewRef.current;
    target.scrollNextPage();
  };
  const prev = () => {
    const target = pageViewRef.current;
    target.goPrev();
  };
  React.useImperativeHandle(ref, () => ({
    to,
    next,
    prev
  }));
  const itemStyle = [styles.itemStyle, itemStyle2()];
  const wrapStyle = [fConStyle(toObj(style || {}))];
  return /*#__PURE__*/React.createElement(DataContext.Provider, {
    value: parent
  }, /*#__PURE__*/React.createElement(View, {
    style: wrapStyle
  }, childCount > 0 ? /*#__PURE__*/React.createElement(PageView, {
    ref: pageViewRef,
    style: {
      width: width || '100%',
      height: height
    },
    styles: styles,
    vertical: isVertical,
    autoplay: autoPlay > 0,
    autoplayInterval: autoPlay || 0,
    infinite: loop,
    selectedIndex: initPage,
    dotStyle: {
      backgroundColor: paginationBgColor
    },
    dotActiveStyle: {
      backgroundColor: paginationColor
    },
    afterChange: onChange,
    dots: paginationVisible || !!pageContent,
    pagination: pageContent ? () => {
      return pageContent;
    } : undefined
  }, React.Children.map(childs, (child, index) => {
    return /*#__PURE__*/React.createElement(View, {
      style: itemStyle,
      key: index
    }, child);
  })) : null));
});
Swiper.defaultProps = defaultProps;
Swiper.displayName = 'NutSwiper';
//# sourceMappingURL=swiper.js.map