import React, { useEffect, useState } from 'react';
import { View, Text } from 'react-native';
import Icon from '../icon';
import fConStyle from '../utils/filter-container-style';
import toObj from '../utils/style-to-obj';
import { useConfig } from '../configprovider';
import tableStyles from './styles';
const defaultProps = {
  style: {},
  columns: [],
  data: [],
  bordered: true,
  striped: false,
  noData: '暂无数据'
};
export const Table = props => {
  const {
    locale,
    theme
  } = useConfig();
  const styles = tableStyles(theme);
  defaultProps.noData = locale.noData;
  const {
    style,
    columns,
    data,
    bordered,
    summary,
    striped,
    noData,
    onSorter
  } = {
    ...defaultProps,
    ...props
  };
  const [curData, setCurData] = useState(data);
  useEffect(() => {
    if (data && String(data) !== String(curData)) {
      setCurData(data);
    }
  }, [data]);
  const handleSorterClick = item => {
    if (item.sorter) {
      onSorter && onSorter(item, curData);
      if (typeof item.sorter === 'function') {
        setCurData(curData.sort(item.sorter));
      } else {
        setCurData(item.sorter === 'default' ? curData.sort() : curData);
      }
    }
  };
  const cellClasses = item => {
    return [props.bordered ? styles.trBorder : {}, item.align ? styles[`trAlign${item.align}`] : {}];
  };
  const getColumnItem = value => {
    return columns.filter(item => item.key === value)[0];
  };
  const renderHeadCells = () => {
    return columns.map((item, index) => {
      return /*#__PURE__*/React.createElement(View, {
        style: [styles.mainHeadTh, ...cellClasses(item), index === columns.length - 1 && bordered ? styles.rightBorder : {}],
        key: item.key,
        onTouchStart: () => {
          if (item.sorter) {
            handleSorterClick(item);
          }
        }
      }, /*#__PURE__*/React.createElement(Text, {
        style: styles.title
      }, item.title), item.sorter ? /*#__PURE__*/React.createElement(Icon, {
        name: "down-arrow",
        size: 12
      }) : null);
    });
  };
  const sortDataItem = () => {
    return columns.map(columns => {
      return [columns.key, columns.render];
    });
  };
  const renderBodyTds = item => {
    return sortDataItem().map((_ref, index) => {
      let [value, render] = _ref;
      return /*#__PURE__*/React.createElement(View, {
        style: [styles.trtd, ...cellClasses(getColumnItem(value)), index === sortDataItem().length - 1 && bordered ? styles.rightBorder : {}],
        key: value
      }, typeof item[value] === 'function' || typeof render === 'function' ? render ? render(item) : item[value](item) : /*#__PURE__*/React.createElement(Text, null, item[value]));
    });
  };
  const renderBoyTrs = () => {
    return curData === null || curData === void 0 ? void 0 : curData.map((item, index) => {
      return /*#__PURE__*/React.createElement(View, {
        style: [styles.mainBodyTr, index % 2 === 1 && striped ? {
          backgroundColor: '#f4f4f4'
        } : {}],
        key: index
      }, renderBodyTds(item));
    });
  };
  const wrapStyle = [styles.container, bordered ? styles.tableBorder : {}, fConStyle(toObj(style || {}))];
  const mainStyle = [styles.mainStyle, striped ? styles.mainStriped : {}];
  return /*#__PURE__*/React.createElement(View, {
    style: wrapStyle
  }, /*#__PURE__*/React.createElement(View, {
    style: mainStyle
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.mainHead
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.mainHeadTr, striped ? {
      backgroundColor: '#f4f4f4'
    } : {}]
  }, renderHeadCells())), /*#__PURE__*/React.createElement(View, {
    style: styles.mainBody
  }, renderBoyTrs())), summary ? /*#__PURE__*/React.createElement(View, {
    style: styles.summary
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.summaryText
  }, summary)) : null, curData.length === 0 ? /*#__PURE__*/React.createElement(View, {
    style: styles.nodata
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.nodataText
  }, noData)) : null);
};
Table.defaultProps = defaultProps;
Table.displayName = 'NutTable';
//# sourceMappingURL=table.js.map