import React, { useEffect, useState, useRef } from 'react';
import { View } from 'react-native';
import { useConfig } from '../configprovider';
import Input from '../input';
import textareaStyles from './styles';
const defaultProps = {
  defaultValue: '',
  textAlign: 'left',
  limitshow: false,
  maxlength: '',
  rows: '2',
  placeholder: '',
  readonly: false,
  disabled: false,
  autosize: false
};
export const TextArea = props => {
  const {
    locale,
    theme
  } = useConfig();
  const styles = textareaStyles(theme);
  const {
    defaultValue,
    textAlign,
    limitshow,
    maxlength,
    rows,
    placeholder,
    readonly,
    disabled,
    autosize,
    style,
    onChange,
    onBlur,
    onFocus
  } = {
    ...defaultProps,
    ...props
  };

  //   const textareaBem = bem('textarea')
  const [inputValue, SetInputValue] = useState('');
  const textareaRef = useRef(null);
  useEffect(() => {
    let initValue = defaultValue;
    if (initValue && maxlength && [...initValue].length > Number(maxlength)) {
      initValue = initValue.substring(0, Number(maxlength));
    }
    SetInputValue(initValue);
    if (autosize) {
      setTimeout(() => {
        setContentHeight();
      });
    }
  }, [defaultValue, autosize]);
  useEffect(() => {
    if (inputValue) {
      if (autosize) {
        setContentHeight();
      }
    }
  }, [inputValue]);
  const setContentHeight = () => {
    const textarea = textareaRef.current;
    if (textarea) {
      textarea.setNativeProps({
        style: {
          height: 'auto'
        }
      });
    }
  };
  const textChange = (value, event) => {
    console.log(value);
    if (maxlength && [...value].length > Number(maxlength)) {
      value = value.substring(0, Number(maxlength));
    }
    SetInputValue(value);
    onChange && onChange(value, event);
  };
  const textFocus = event => {
    if (disabled) return;
    if (readonly) return;
    onFocus && onFocus(event);
  };
  const textBlur = (value, event) => {
    if (disabled) return;
    if (readonly) return;
    onChange && onChange(value, event);
    onBlur && onBlur(event);
  };
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.nutTextarea, disabled && styles.nutTextarea__disabled]
  }, /*#__PURE__*/React.createElement(Input, {
    type: 'textarea',
    ref: textareaRef,
    style: {
      ...styles.nutTextarea__textarea,
      ...style
    },
    inputAlign: textAlign,
    showWordLimit: limitshow,
    disabled: disabled,
    readonly: readonly,
    defaultValue: inputValue,
    onChange: (value, e) => {
      textChange(value, e);
    },
    onBlur: (value, e) => {
      textBlur(value, e);
    },
    onFocus: e => {
      textFocus(e);
    },
    rows: rows,
    maxlength: maxlength < 0 ? 0 : maxlength,
    placeholder: placeholder || locale.placeholder
  }));
};
TextArea.defaultProps = defaultProps;
TextArea.displayName = 'NutTextArea';
//# sourceMappingURL=textarea.js.map